/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_2MpiT648);
  numBytes += sLine_init(&sLine_ihxa2Dt4);
  numBytes += sLine_init(&sLine_TUotKkqF);
  numBytes += sLine_init(&sLine_Sjv4u47u);
  numBytes += sLine_init(&sLine_MvM3pL8B);
  numBytes += sBiquad_init(&sBiquad_s_mWNxxp4i);
  numBytes += sLine_init(&sLine_et17LT5F);
  numBytes += sLine_init(&sLine_VA5rFCuh);
  numBytes += sLine_init(&sLine_duLQELrS);
  numBytes += sLine_init(&sLine_oGOZKPio);
  numBytes += sBiquad_init(&sBiquad_s_NdjjWDLn);
  numBytes += sLine_init(&sLine_Mk7UQMb3);
  numBytes += sLine_init(&sLine_vd3GWE4x);
  numBytes += sLine_init(&sLine_MML8y9Wb);
  numBytes += sLine_init(&sLine_4ap6Fpn7);
  numBytes += sLine_init(&sLine_w1AuIthx);
  numBytes += sBiquad_init(&sBiquad_s_2SerxhIZ);
  numBytes += sLine_init(&sLine_dmZzR6wY);
  numBytes += sLine_init(&sLine_r9XBIiK9);
  numBytes += sLine_init(&sLine_NQ1qTYDh);
  numBytes += sLine_init(&sLine_2WifDiJS);
  numBytes += sLine_init(&sLine_14KH4T7T);
  numBytes += sBiquad_init(&sBiquad_s_I744rcZQ);
  numBytes += sLine_init(&sLine_qJkLsPcl);
  numBytes += sLine_init(&sLine_3DKRGW5S);
  numBytes += sLine_init(&sLine_PIUYuG98);
  numBytes += sLine_init(&sLine_rwdCeEGJ);
  numBytes += sBiquad_init(&sBiquad_s_21TTu73Y);
  numBytes += sLine_init(&sLine_ETdqyVsQ);
  numBytes += sLine_init(&sLine_Ndo9TACG);
  numBytes += sLine_init(&sLine_kgF66fMt);
  numBytes += sLine_init(&sLine_1VGE0G6h);
  numBytes += sLine_init(&sLine_IYYCDG1p);
  numBytes += sBiquad_init(&sBiquad_s_UuvmkjtP);
  numBytes += sLine_init(&sLine_L9wy0SbF);
  numBytes += sTabread_init(&sTabread_BHAehiYw, &hTable_ZhkXHBMe, true);
  numBytes += sLine_init(&sLine_2z4p89yi);
  numBytes += sLine_init(&sLine_Rtwni67f);
  numBytes += sTabread_init(&sTabread_9DhyWZe9, &hTable_QVsziLM8, true);
  numBytes += sLine_init(&sLine_f0gejDFD);
  numBytes += sRPole_init(&sRPole_t8Y2SeGk);
  numBytes += sDel1_init(&sDel1_1nlOCVEf);
  numBytes += sTabwrite_init(&sTabwrite_oKwGIwwi, &hTable_ZhkXHBMe);
  numBytes += sRPole_init(&sRPole_P0Z1Lc1N);
  numBytes += sDel1_init(&sDel1_Omp0QztU);
  numBytes += sTabwrite_init(&sTabwrite_PgfyetM3, &hTable_QVsziLM8);
  numBytes += sLine_init(&sLine_O7OuF9HX);
  numBytes += sLine_init(&sLine_TnYRHVyD);
  numBytes += sRPole_init(&sRPole_5A4MzZJO);
  numBytes += sEnv_init(&sEnv_idzMh9sT, 1024, 512);
  numBytes += sRPole_init(&sRPole_GmZ5XVHZ);
  numBytes += sLine_init(&sLine_X7pWH3wy);
  numBytes += sLine_init(&sLine_cCE8JiVQ);
  numBytes += sRPole_init(&sRPole_n2e1TkD0);
  numBytes += sEnv_init(&sEnv_0hJNJ1CW, 1024, 512);
  numBytes += sRPole_init(&sRPole_2rsRoSpd);
  numBytes += sLine_init(&sLine_PsuWTzC8);
  numBytes += sTabread_init(&sTabread_QRXUWCl6, &hTable_iXucTj5e, true);
  numBytes += sLine_init(&sLine_Eyq1UhVs);
  numBytes += sLine_init(&sLine_I2xYjQg7);
  numBytes += sTabread_init(&sTabread_k5q0SgAa, &hTable_DNky5wiS, true);
  numBytes += sLine_init(&sLine_WYEUeB51);
  numBytes += sRPole_init(&sRPole_Zq6s2x3M);
  numBytes += sDel1_init(&sDel1_6NhlGK18);
  numBytes += sTabwrite_init(&sTabwrite_nIXEbvKF, &hTable_iXucTj5e);
  numBytes += sRPole_init(&sRPole_cHe8faaM);
  numBytes += sDel1_init(&sDel1_H1qDEEXH);
  numBytes += sTabwrite_init(&sTabwrite_qzfDxLi3, &hTable_DNky5wiS);
  numBytes += sLine_init(&sLine_zpFu6NEx);
  numBytes += sLine_init(&sLine_lMl5VLzP);
  numBytes += sRPole_init(&sRPole_Doq60Cmm);
  numBytes += sEnv_init(&sEnv_476lIAOO, 1024, 512);
  numBytes += sRPole_init(&sRPole_XhFa8jyn);
  numBytes += sLine_init(&sLine_4BeIaWg0);
  numBytes += sLine_init(&sLine_eOLu3U6x);
  numBytes += sRPole_init(&sRPole_MGHLuNKT);
  numBytes += sEnv_init(&sEnv_uqw5blMT, 1024, 512);
  numBytes += sRPole_init(&sRPole_fsZFOZH5);
  numBytes += sLine_init(&sLine_kuQyRfmZ);
  numBytes += sTabread_init(&sTabread_pnTWeUHV, &hTable_bqiS5quI, true);
  numBytes += sLine_init(&sLine_4rIt9OwS);
  numBytes += sLine_init(&sLine_VXQ6647x);
  numBytes += sTabread_init(&sTabread_VnMc8tu7, &hTable_iIguDIux, true);
  numBytes += sLine_init(&sLine_FuVhpRJE);
  numBytes += sRPole_init(&sRPole_djQDRWja);
  numBytes += sDel1_init(&sDel1_8puePUoS);
  numBytes += sTabwrite_init(&sTabwrite_iePjZD9p, &hTable_bqiS5quI);
  numBytes += sRPole_init(&sRPole_jW6Sz8mx);
  numBytes += sDel1_init(&sDel1_VbWiSegL);
  numBytes += sTabwrite_init(&sTabwrite_Rw9AfzaL, &hTable_iIguDIux);
  numBytes += sLine_init(&sLine_NYYMYq9u);
  numBytes += sLine_init(&sLine_svDIXkYh);
  numBytes += sRPole_init(&sRPole_B82F7sS9);
  numBytes += sEnv_init(&sEnv_YxIu2KqR, 1024, 512);
  numBytes += sRPole_init(&sRPole_NixnSUfZ);
  numBytes += sLine_init(&sLine_EblTejTF);
  numBytes += sLine_init(&sLine_tZlMqJEQ);
  numBytes += sRPole_init(&sRPole_P42YgaSM);
  numBytes += sEnv_init(&sEnv_roJWg0Yp, 1024, 512);
  numBytes += sRPole_init(&sRPole_1qbEudMI);
  numBytes += cVar_init_f(&cVar_9K6EzhZk, 0.0f);
  numBytes += cVar_init_f(&cVar_4tXxnlGC, 0.0f);
  numBytes += cVar_init_f(&cVar_8haFuEXX, 0.0f);
  numBytes += cVar_init_f(&cVar_skBdHZNw, 0.0f);
  numBytes += cSlice_init(&cSlice_szL9B0oJ, 1, -1);
  numBytes += cVar_init_f(&cVar_eL06RVxC, 1337.0f);
  numBytes += cVar_init_f(&cVar_BALlMcNL, 0.0f);
  numBytes += cIf_init(&cIf_Oo3AbzSB, false);
  numBytes += cIf_init(&cIf_nrgGTJOT, false);
  numBytes += cBinop_init(&cBinop_qNDZlhpx, 0.0f); // __pow
  numBytes += cIf_init(&cIf_BcZ2wWx3, false);
  numBytes += cBinop_init(&cBinop_1mnnSwkv, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_KAXMuwrv, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_YuyrT7W2, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Rb4E6LVJ, 0.0f);
  numBytes += cIf_init(&cIf_Yg5NcEVy, false);
  numBytes += cIf_init(&cIf_VkRGMbuK, false);
  numBytes += cBinop_init(&cBinop_Jp7pWFAw, 0.0f); // __pow
  numBytes += cIf_init(&cIf_VUMQcFXB, false);
  numBytes += cBinop_init(&cBinop_5YgmyxXr, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_JDskSItV, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_vaOkrRwK, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_qxFLug7l, 0.0f);
  numBytes += cIf_init(&cIf_wR5kyO3r, false);
  numBytes += cIf_init(&cIf_kZ8bjkKe, false);
  numBytes += cBinop_init(&cBinop_s1XSHEup, 0.0f); // __pow
  numBytes += cIf_init(&cIf_efXXZRRJ, false);
  numBytes += cBinop_init(&cBinop_tmPsvY1w, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_gNBzQTIc, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_stChHt7R, -15.0f); // __eq
  numBytes += cIf_init(&cIf_48eX9l3J, false);
  numBytes += cSlice_init(&cSlice_gYwmVjp3, 1, -1);
  numBytes += cVar_init_f(&cVar_nBdXZ5fK, 0.0f);
  numBytes += cSlice_init(&cSlice_15cW60kw, 1, -1);
  numBytes += cVar_init_f(&cVar_rGCgnthK, 0.0f);
  numBytes += cSlice_init(&cSlice_6JO07H2V, 1, -1);
  numBytes += cVar_init_f(&cVar_CrrXzfju, 0.0f);
  numBytes += cSlice_init(&cSlice_P25H0vcG, 1, -1);
  numBytes += cVar_init_f(&cVar_svKJDjUY, 0.313f);
  numBytes += cBinop_init(&cBinop_FJcLy8d1, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_wpkHW1g6, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ReOWPeCj, 0.0f);
  numBytes += cVar_init_f(&cVar_wKppoZJP, 1337.0f);
  numBytes += cVar_init_f(&cVar_04okwKye, 0.3f);
  numBytes += cBinop_init(&cBinop_gvbEwwaR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8OcXmqEZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FfDUSg6I, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vrakOLhQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YEVffZHg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DmfPEa95, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_G2FVd3ms, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_vfkkWc0B, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_4yY3n3xu, 0.0f);
  numBytes += cVar_init_f(&cVar_eYQcZ6MQ, 1337.0f);
  numBytes += cVar_init_f(&cVar_Uwi0PLDh, 0.313f);
  numBytes += cBinop_init(&cBinop_vU7zvt1z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Kje2wcjo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JXIaCMyu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FvZTRlo8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0geHGp4W, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hemEosHF, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_K61unuU4, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ZIKsMCEZ, 0.0f);
  numBytes += cVar_init_f(&cVar_cfBvbOuF, 1037.0f);
  numBytes += cVar_init_f(&cVar_dmQYvNHp, 0.4f);
  numBytes += cBinop_init(&cBinop_fcmBqiwr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SATJtXJ7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MxerDJkg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IM3dX9Zs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_c9dv6ELg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vB0MZajK, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Y9rh05Qt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Nk6SXYYA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CwgoX2NB, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_1qIhkj29, 1, -1);
  numBytes += cVar_init_f(&cVar_7ebw265P, 1337.0f);
  numBytes += cVar_init_f(&cVar_Bd10jSk9, 0.0f);
  numBytes += cIf_init(&cIf_nDq3BAqE, false);
  numBytes += cIf_init(&cIf_fg5ocyMB, false);
  numBytes += cBinop_init(&cBinop_UVvUkd3W, 0.0f); // __pow
  numBytes += cIf_init(&cIf_wnfK5Tl5, false);
  numBytes += cBinop_init(&cBinop_B8g7gm4V, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_8SXgn7hd, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_jBOmEqSC, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_QNEQxQkp, 0.0f);
  numBytes += cIf_init(&cIf_VXKWz8hM, false);
  numBytes += cIf_init(&cIf_sOYhfo44, false);
  numBytes += cBinop_init(&cBinop_BmIqToWE, 0.0f); // __pow
  numBytes += cIf_init(&cIf_JGXaFqQy, false);
  numBytes += cBinop_init(&cBinop_Zbhanzsb, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Kv3ENKJI, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_2pB748q8, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_R1tZj1hy, 0.0f);
  numBytes += cIf_init(&cIf_wJJq0goy, false);
  numBytes += cIf_init(&cIf_K8AGfv5Z, false);
  numBytes += cBinop_init(&cBinop_dH8FjgLZ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_quSYb07m, false);
  numBytes += cBinop_init(&cBinop_xAR3sQli, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_kaz5VU2y, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_NFp2A1j7, -15.0f); // __eq
  numBytes += cIf_init(&cIf_A6fjV44P, false);
  numBytes += cSlice_init(&cSlice_p4SQ44v1, 1, -1);
  numBytes += cVar_init_f(&cVar_tz5Wrkie, 0.0f);
  numBytes += cSlice_init(&cSlice_13wGXgH7, 1, -1);
  numBytes += cVar_init_f(&cVar_jnR0RceH, 0.0f);
  numBytes += cSlice_init(&cSlice_kQ04dGRT, 1, -1);
  numBytes += cVar_init_f(&cVar_lAoPmes5, 0.0f);
  numBytes += cSlice_init(&cSlice_I1VtcSl6, 1, -1);
  numBytes += cVar_init_f(&cVar_QxXlFph3, 0.313f);
  numBytes += cBinop_init(&cBinop_4ypkrLjS, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_DQu62pMg, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_IIu05yFw, 0.0f);
  numBytes += cVar_init_f(&cVar_zcs1Z90u, 1337.0f);
  numBytes += cVar_init_f(&cVar_atF22fW4, 0.3f);
  numBytes += cBinop_init(&cBinop_U9ywQ3MA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wsLbeHHq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Q0UiXzla, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9rIcyZ2K, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4HC27nVh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_U2whlAyt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_j55lZtFG, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_SNQyKrTY, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_8cB9JSBM, 0.0f);
  numBytes += cVar_init_f(&cVar_4JIAjRFc, 1337.0f);
  numBytes += cVar_init_f(&cVar_LJu5p3Dg, 0.313f);
  numBytes += cBinop_init(&cBinop_dkwrDPPP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3nG7CFva, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YIkeTgY4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_J2gr0kST, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_o6v6y7Ab, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bHNFK20p, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ams3gu6u, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_fTwY6S7N, 0.0f);
  numBytes += cVar_init_f(&cVar_cK4Xxqaa, 1037.0f);
  numBytes += cVar_init_f(&cVar_lAIhn97V, 0.4f);
  numBytes += cBinop_init(&cBinop_WF0ZfEtJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Lowz1wn1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Uo4i80nV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_J6socpt4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WCSzdCZ2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PiHyuCem, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_VCrWoiaz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0uyzyeYp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Xllp4blt, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_GCYDCH7K, 5705.6f);
  numBytes += cVar_init_f(&cVar_PT4GzEsn, 313.3f);
  numBytes += cBinop_init(&cBinop_Ka5md4q2, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_KUOL0Fjx, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_QtYPzDh1, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_NkvbTTvN, 0.0f);
  numBytes += cVar_init_f(&cVar_kVGDrYAM, 0.0f);
  numBytes += cVar_init_f(&cVar_6I8XEJ1O, 0.0f);
  numBytes += cVar_init_f(&cVar_e8tgKWrc, 0.0f);
  numBytes += cVar_init_f(&cVar_eLvMGduN, 0.0f);
  numBytes += cVar_init_f(&cVar_4OZYgtIN, 0.0f);
  numBytes += cVar_init_f(&cVar_3M6cWgcG, 0.0f);
  numBytes += cVar_init_f(&cVar_oECDjVgs, 0.0f);
  numBytes += cVar_init_f(&cVar_vSjk6RCF, 0.0f);
  numBytes += cVar_init_f(&cVar_Gbo0ywP1, 0.0f);
  numBytes += cVar_init_f(&cVar_C7zNzSu1, 0.0f);
  numBytes += cVar_init_f(&cVar_KApAWxsj, 0.0f);
  numBytes += cSlice_init(&cSlice_wkV1Y78Y, 1, -1);
  numBytes += cVar_init_f(&cVar_RaK3I23A, 0.5f);
  numBytes += cSlice_init(&cSlice_LwEKUOYd, 1, -1);
  numBytes += cVar_init_f(&cVar_80CZ8oDr, 0.2f);
  numBytes += cSlice_init(&cSlice_58Rhc5BL, 1, -1);
  numBytes += cVar_init_f(&cVar_O6lgFkxU, 500.0f);
  numBytes += sVarf_init(&sVarf_X2bjEglF, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_3quvafgk, 600.0f);
  numBytes += cBinop_init(&cBinop_tducXrGb, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_rCnszJKm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ovMCqtx2, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_cRliIBoH, 600.0f);
  numBytes += cBinop_init(&cBinop_aRKamtg1, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_XsVel6Nf, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_4NqMeyxQ, 4000.0f);
  numBytes += cBinop_init(&cBinop_6Ty6p4u7, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_lVKQm5N2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_F6CXE34I, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_s5ghIzpM, 4000.0f);
  numBytes += cBinop_init(&cBinop_kpDOItcE, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_GznuRjsj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_O8jWdoHs, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_omgSxWQv, false);
  numBytes += cBinop_init(&cBinop_atTASeMl, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_WYUqzyM6, 20.0f);
  numBytes += cBinop_init(&cBinop_01VpmqlK, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ivNGQ2hZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aHX52VRt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VnNIqspL, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_ixhMkcqF, false);
  numBytes += cBinop_init(&cBinop_HTFuyS1Q, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_WrJu9tF8, 20.0f);
  numBytes += cBinop_init(&cBinop_uoSY12vu, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_S78jRPEJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ljY3vBxr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_P1jV1PEO, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_L2EeecZh, 1, -1);
  numBytes += cVar_init_f(&cVar_xfAub66P, 0.25f);
  numBytes += cDelay_init(this, &cDelay_299AZzQT, 0.0f);
  numBytes += cDelay_init(this, &cDelay_u2WI86OC, 0.0f);
  numBytes += hTable_init(&hTable_ZhkXHBMe, 256);
  numBytes += cTabhead_init(&cTabhead_kKrKBgH0, &hTable_ZhkXHBMe);
  numBytes += cVar_init_s(&cVar_x1xIkQ9p, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_N9qkUCDh, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Y1vPjL64, 0.0f);
  numBytes += cBinop_init(&cBinop_Mliwy4jo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YYZtXYfn, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ZrchINVr, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_mN8SHJIn, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_IZlrPGwf, 0.0f);
  numBytes += cDelay_init(this, &cDelay_lWgEp5Qh, 0.0f);
  numBytes += hTable_init(&hTable_QVsziLM8, 256);
  numBytes += cTabhead_init(&cTabhead_RnQiAKn2, &hTable_QVsziLM8);
  numBytes += cVar_init_s(&cVar_sRmzWkhF, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_Xl8fiUHt, 0.0f);
  numBytes += cDelay_init(this, &cDelay_yG3zcDJA, 0.0f);
  numBytes += cBinop_init(&cBinop_5wQqil91, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lBamZ0ym, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_VJIQL4LX, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_KXW7vv0w, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_ITpFJ3o4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DgPQ5MeU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FPRlUv2i, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9fqlzBXs, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_f3sbJEKH, 1, -1);
  numBytes += cVar_init_f(&cVar_qNJC89rL, 0.5f);
  numBytes += cSlice_init(&cSlice_rqvb7z54, 1, -1);
  numBytes += cVar_init_f(&cVar_Xi511yDy, 0.2f);
  numBytes += cSlice_init(&cSlice_vD5WvQfk, 1, -1);
  numBytes += cVar_init_f(&cVar_lK6nCmOc, 500.0f);
  numBytes += sVarf_init(&sVarf_7qJ6v8qg, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_3kSN98pg, 600.0f);
  numBytes += cBinop_init(&cBinop_SePGIl1c, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_RQJt7UMI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CBRXELsm, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Pu7DA4i6, 600.0f);
  numBytes += cBinop_init(&cBinop_KT0IoBAg, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_fp26OIgO, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_zDlEjLs6, 4000.0f);
  numBytes += cBinop_init(&cBinop_ztQlEfLy, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_yUji54x6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Qai4odmV, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_NKqYXiOe, 4000.0f);
  numBytes += cBinop_init(&cBinop_fZtH8F4t, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_s5yqKLSQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hVrWLdi8, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_ESiHpQVj, false);
  numBytes += cBinop_init(&cBinop_w9fcW9Jn, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_3qjHi6KG, 20.0f);
  numBytes += cBinop_init(&cBinop_7uAEGUMz, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_BYZb8kxx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DuQKnmd4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_w0TFJN1c, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_8X6y93QT, false);
  numBytes += cBinop_init(&cBinop_9hjjFUd0, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_FKI2P7D5, 20.0f);
  numBytes += cBinop_init(&cBinop_V2uOg5EM, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_mFCSHpVE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6wev00gr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4ZoQ17C6, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_eNlIavjv, 1, -1);
  numBytes += cVar_init_f(&cVar_RgUH9nqQ, 0.25f);
  numBytes += cDelay_init(this, &cDelay_oUjcMmcL, 0.0f);
  numBytes += cDelay_init(this, &cDelay_9rflHN7a, 0.0f);
  numBytes += hTable_init(&hTable_iXucTj5e, 256);
  numBytes += cTabhead_init(&cTabhead_wVwwKnFc, &hTable_iXucTj5e);
  numBytes += cVar_init_s(&cVar_sF1ZjPJH, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_y29EW3Wo, 0.0f);
  numBytes += cDelay_init(this, &cDelay_g2Ziypag, 0.0f);
  numBytes += cBinop_init(&cBinop_QtrdYkE9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ggRvSnn1, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_rzqF162A, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Nxj6znGR, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_kU7rU8ud, 0.0f);
  numBytes += cDelay_init(this, &cDelay_21DLu2q4, 0.0f);
  numBytes += hTable_init(&hTable_DNky5wiS, 256);
  numBytes += cTabhead_init(&cTabhead_DoG2FYlI, &hTable_DNky5wiS);
  numBytes += cVar_init_s(&cVar_HHmQ3HlG, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_WhWxFRkN, 0.0f);
  numBytes += cDelay_init(this, &cDelay_tUFPvisn, 0.0f);
  numBytes += cBinop_init(&cBinop_IBciKKr8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lUOcSdFH, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ZLDq5jIF, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_JKUf9FTK, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_LKAr5mxL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LPuyhBSB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_epnkhGKF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BrG2ex7S, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_SEjcGFMb, 1, -1);
  numBytes += cVar_init_f(&cVar_O6aPZ2pp, 0.5f);
  numBytes += cSlice_init(&cSlice_Bo0ZQPqI, 1, -1);
  numBytes += cVar_init_f(&cVar_YRiRtKoH, 0.2f);
  numBytes += cSlice_init(&cSlice_XTKQdY4q, 1, -1);
  numBytes += cVar_init_f(&cVar_GbWs000S, 500.0f);
  numBytes += sVarf_init(&sVarf_b1SAE6bB, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_mWY6Gmf9, 600.0f);
  numBytes += cBinop_init(&cBinop_WRxrUcD4, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_7WDvGsGh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4Cnf9xuR, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_1Vn4LyU6, 600.0f);
  numBytes += cBinop_init(&cBinop_S1J03hNq, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_Tt0X1jcd, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_PguyLbSn, 4000.0f);
  numBytes += cBinop_init(&cBinop_nRQRumEd, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Qnu5SmC1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BEerFRF6, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_A3IHHq6Q, 4000.0f);
  numBytes += cBinop_init(&cBinop_tkYDsgN2, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_cTQ5yx7M, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_K9IfT6kN, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_Fzn4NGZW, false);
  numBytes += cBinop_init(&cBinop_fAJPgBWi, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_LE8lQtbZ, 20.0f);
  numBytes += cBinop_init(&cBinop_rxmqTBBv, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Qy0xkJaV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BTwM9L8s, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rKapemfn, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_whRWFk1U, false);
  numBytes += cBinop_init(&cBinop_8hUpXU63, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_YiV5Wpnx, 20.0f);
  numBytes += cBinop_init(&cBinop_FLZ1zB5J, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_K6VZeEC9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8u9MtGVl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_M9VCZmam, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_EBtSeyTA, 1, -1);
  numBytes += cVar_init_f(&cVar_F2Hkc7NY, 0.25f);
  numBytes += cDelay_init(this, &cDelay_wxIUCWKu, 0.0f);
  numBytes += cDelay_init(this, &cDelay_VsUokA1Z, 0.0f);
  numBytes += hTable_init(&hTable_bqiS5quI, 256);
  numBytes += cTabhead_init(&cTabhead_U3eAW14U, &hTable_bqiS5quI);
  numBytes += cVar_init_s(&cVar_xjFDSqMK, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_YQp27iHF, 0.0f);
  numBytes += cDelay_init(this, &cDelay_jVPw6xJw, 0.0f);
  numBytes += cBinop_init(&cBinop_475eLQvT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qFxKFAhm, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_MLb3dSSC, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_7lc8xFvJ, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_jwlDV6O9, 0.0f);
  numBytes += cDelay_init(this, &cDelay_L3snhHOf, 0.0f);
  numBytes += hTable_init(&hTable_iIguDIux, 256);
  numBytes += cTabhead_init(&cTabhead_U24O6zxy, &hTable_iIguDIux);
  numBytes += cVar_init_s(&cVar_oH3J3pKX, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_oPnM2ddA, 0.0f);
  numBytes += cDelay_init(this, &cDelay_rgZ0I8Ko, 0.0f);
  numBytes += cBinop_init(&cBinop_dD5JDzOZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yQBYDbZX, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ApR0Z1jL, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Ee1xMoiV, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_qqABW3JY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JCKneiLy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_a4BL4mle, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lXaurTNU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_e8SGvQom, 1.0f);
  numBytes += cIf_init(&cIf_1fOtK75r, false);
  numBytes += cIf_init(&cIf_K8bdEZgw, false);
  numBytes += cVar_init_f(&cVar_8mCIUVCV, 0.0f);
  numBytes += cVar_init_f(&cVar_166D6dMy, 0.0f);
  numBytes += cVar_init_f(&cVar_yxTCAXmb, 1.0f);
  numBytes += cIf_init(&cIf_MGRyxWuA, false);
  numBytes += cIf_init(&cIf_Wo0CX1kM, false);
  numBytes += cVar_init_f(&cVar_f0XtACiw, 0.0f);
  numBytes += cVar_init_f(&cVar_fGQp8JdV, 0.0f);
  numBytes += cVar_init_f(&cVar_DPKOMGkw, 1.0f);
  numBytes += cIf_init(&cIf_GpvMrZ4N, false);
  numBytes += cIf_init(&cIf_RJm0WKwk, false);
  numBytes += cVar_init_f(&cVar_sleystaz, 0.0f);
  numBytes += cVar_init_f(&cVar_wQKhwR8l, 0.0f);
  numBytes += cVar_init_f(&cVar_MEC49OZJ, 60000.0f);
  numBytes += cVar_init_f(&cVar_pfNpKvzF, 500.0f);
  numBytes += cSlice_init(&cSlice_c55JulEv, 1, -1);
  numBytes += cSlice_init(&cSlice_GAYhMoIf, 1, -1);
  numBytes += cVar_init_f(&cVar_xqhtGuhA, 0.0f);
  numBytes += cIf_init(&cIf_zcv66dDl, false);
  numBytes += cBinop_init(&cBinop_yIavPIZz, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_UkUN1eN7, 120.0f);
  numBytes += cBinop_init(&cBinop_nR0jqm4e, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_bmHtl2TY, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_E7gpAWu0, 60000.0f);
  numBytes += cVar_init_f(&cVar_588vX11u, 500.0f);
  numBytes += cSlice_init(&cSlice_I67l3l8l, 1, -1);
  numBytes += cSlice_init(&cSlice_XUMAN3T8, 1, -1);
  numBytes += cVar_init_f(&cVar_gNI5rN2P, 0.0f);
  numBytes += cIf_init(&cIf_B8DIKr7f, false);
  numBytes += cBinop_init(&cBinop_2jUBamDg, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_JH8TRNMP, 120.0f);
  numBytes += cBinop_init(&cBinop_aiFnLhp9, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_tCV8m4CJ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ovKwLRbz, 60000.0f);
  numBytes += cVar_init_f(&cVar_EXHsuyue, 500.0f);
  numBytes += cSlice_init(&cSlice_xf4hrMDq, 1, -1);
  numBytes += cSlice_init(&cSlice_hU9uElxt, 1, -1);
  numBytes += cVar_init_f(&cVar_d9rU2L4S, 0.0f);
  numBytes += cIf_init(&cIf_ze1FLYWU, false);
  numBytes += cBinop_init(&cBinop_YOBmjGru, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_DY6IRRJm, 120.0f);
  numBytes += cBinop_init(&cBinop_sqqEXtxe, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_jexJFChN, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_q8edYgq2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eJX0Fbmm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LKyF6c6Y, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WSA0EmMH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kEcDlgMg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ikCcnThL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0M1XbEz4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l7DfYC8q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YE4rYNXA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_D4pnsN6b, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_idzMh9sT);
  sEnv_free(&sEnv_0hJNJ1CW);
  sEnv_free(&sEnv_476lIAOO);
  sEnv_free(&sEnv_uqw5blMT);
  sEnv_free(&sEnv_YxIu2KqR);
  sEnv_free(&sEnv_roJWg0Yp);
  hTable_free(&hTable_ZhkXHBMe);
  hTable_free(&hTable_QVsziLM8);
  hTable_free(&hTable_iXucTj5e);
  hTable_free(&hTable_DNky5wiS);
  hTable_free(&hTable_bqiS5quI);
  hTable_free(&hTable_iIguDIux);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_ZhkXHBMe; // del-1349-delayL
    case 0x19A00729: return &hTable_QVsziLM8; // del-1349-delayR
    case 0x584C8281: return &hTable_iXucTj5e; // del-1428-delayL
    case 0x54BF59F6: return &hTable_DNky5wiS; // del-1428-delayR
    case 0xBCE693A: return &hTable_bqiS5quI; // del-1507-delayL
    case 0x95A380B3: return &hTable_iIguDIux; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ary8fWsT_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_x8hMW9yF_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sACxT3Oy_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HPBqw4vP_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aRa7y4Ps_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vZt7J1l6_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bZDZBPNk_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yVuAzmi8_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7wVrtn2v_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nylIk1K4_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_z8yEl8iL_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_koAGPBk9_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AA5BoCUB_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_comxhdk2_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_USKv6yV4_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tZ30Aa7V_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0caZlisb_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_v7GHc9hT_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KT2Uv5JT_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_w49CFvVY_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ggeOqn5Y_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YDs66Ksb_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZgUQ0Wq6_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jnwO4YA0_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cY2o4y3E_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_g1HkUfYg_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wzNu8L86_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SqzbEjA0_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5eiemZrp_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7PR2ebK4_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tZIfJMs2_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Fl5w11gv_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hscY8OiO_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fsPHLeeF_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nTN11LpY_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2Zrd1yCY_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HLYu0QzR_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VFLY7H80_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gi8SkX4B_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uOYIvocj_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iAC0IYzS_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EzkjrWnQ_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xNOpJCkj_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UT2rYG8C_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5Z7pifbR_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qh5w0bMW_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VrMcHY7K_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9KPw4WJ4_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_M2dDOz8h_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5bxpUvHx_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SZoeBqn4_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pD2OMkmo_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MvrF1fwV_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Vn9IU9L4_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K5PK4Gby_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_apRY9lsd_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TBPSKCeb_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RqtNdhU4_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wot8bBgw_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nel4OeW1_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SR8UEidz_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bsANG1IR_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oT9R2PrM_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4qv0PuiS_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_9K6EzhZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rIIO5LAi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_4tXxnlGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tP2yXRiX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_8haFuEXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iS7JA9XO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_skBdHZNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vtPWd1CV_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jUU0DyEJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eWtoOn11_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q8m2ueYD_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_bT9cw7FY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_szL9B0oJ, 0, m, &cSlice_szL9B0oJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_O2O1eMYt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_szL9B0oJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xPQyjJRO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xPQyjJRO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_eL06RVxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xPQyjJRO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_xPQyjJRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cY2o4y3E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_BALlMcNL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_65Cp8dAf_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Oo3AbzSB, 0, m, &cIf_Oo3AbzSB_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Oo3AbzSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_dHy8ZzQ5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_nrgGTJOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_pIOmWe6z_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_97c07eAt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_8EfGYEAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qNDZlhpx, HV_BINOP_POW, 0, m, &cBinop_qNDZlhpx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qNDZlhpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BcZ2wWx3, 0, m, &cIf_BcZ2wWx3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DSqrkeXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_fnmaEaaL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_W3bid7Kz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nrgGTJOT, 0, m, &cIf_nrgGTJOT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_D0xelYaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZMHekA4L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZMHekA4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nrgGTJOT, 1, m, &cIf_nrgGTJOT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_97c07eAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_DSqrkeXg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pIOmWe6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_BcZ2wWx3, 0, m, &cIf_BcZ2wWx3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fnmaEaaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qNDZlhpx, HV_BINOP_POW, 1, m, &cBinop_qNDZlhpx_sendMessage);
  cMsg_8EfGYEAa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_BcZ2wWx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Y9rh05Qt, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_65Cp8dAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Oo3AbzSB, 1, m, &cIf_Oo3AbzSB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dHy8ZzQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KAXMuwrv, HV_BINOP_GREATER_THAN, 1, m, &cBinop_KAXMuwrv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YuyrT7W2, HV_BINOP_EQ, 1, m, &cBinop_YuyrT7W2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zi88LSab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1mnnSwkv, HV_BINOP_ADD, 0, m, &cBinop_1mnnSwkv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1mnnSwkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D0xelYaz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W3bid7Kz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KAXMuwrv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BcZ2wWx3, 1, m, &cIf_BcZ2wWx3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YuyrT7W2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GemmAfJP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_GemmAfJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Y9rh05Qt, m);
}

void Heavy_WSTD_DL3Y::cCast_f746IhJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BALlMcNL, 0, m, &cVar_BALlMcNL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vfKku4Vl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1mnnSwkv, HV_BINOP_ADD, 1, m, &cBinop_1mnnSwkv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KAXMuwrv, HV_BINOP_GREATER_THAN, 0, m, &cBinop_KAXMuwrv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YuyrT7W2, HV_BINOP_EQ, 0, m, &cBinop_YuyrT7W2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_udHuPjOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zi88LSab_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Rb4E6LVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_6EJjyvjR_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Yg5NcEVy, 0, m, &cIf_Yg5NcEVy_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Yg5NcEVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QNEGoov5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_VkRGMbuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_vbf7fZCt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_WjeiPhU3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_2Rg1A4XK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jp7pWFAw, HV_BINOP_POW, 0, m, &cBinop_Jp7pWFAw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Jp7pWFAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VUMQcFXB, 0, m, &cIf_VUMQcFXB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w6iIoXr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_gDLguzI6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Vm28kZZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_TjiFAnm1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Z1tw1g1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VkRGMbuK, 0, m, &cIf_VkRGMbuK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TjiFAnm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VkRGMbuK, 1, m, &cIf_VkRGMbuK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WjeiPhU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_w6iIoXr6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vbf7fZCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_VUMQcFXB, 0, m, &cIf_VUMQcFXB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gDLguzI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jp7pWFAw, HV_BINOP_POW, 1, m, &cBinop_Jp7pWFAw_sendMessage);
  cMsg_2Rg1A4XK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_VUMQcFXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wpMJGVR4_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BZQTYaT0_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Qgukjqdx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_6EJjyvjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yg5NcEVy, 1, m, &cIf_Yg5NcEVy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QNEGoov5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JDskSItV, HV_BINOP_GREATER_THAN, 1, m, &cBinop_JDskSItV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vaOkrRwK, HV_BINOP_EQ, 1, m, &cBinop_vaOkrRwK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_usGU02Rg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5YgmyxXr, HV_BINOP_ADD, 0, m, &cBinop_5YgmyxXr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5YgmyxXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vm28kZZK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z1tw1g1P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JDskSItV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VUMQcFXB, 1, m, &cIf_VUMQcFXB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vaOkrRwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iK1fRx5W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_iK1fRx5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wpMJGVR4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BZQTYaT0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Qgukjqdx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_N0nkBIdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5YgmyxXr, HV_BINOP_ADD, 1, m, &cBinop_5YgmyxXr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JDskSItV, HV_BINOP_GREATER_THAN, 0, m, &cBinop_JDskSItV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vaOkrRwK, HV_BINOP_EQ, 0, m, &cBinop_vaOkrRwK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jhccuJ7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_usGU02Rg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QbMlYcRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Rb4E6LVJ, 0, m, &cVar_Rb4E6LVJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_qxFLug7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Jh8CJMR5_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_wR5kyO3r, 0, m, &cIf_wR5kyO3r_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_wR5kyO3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qOOFPJ6F_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_kZ8bjkKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_cHA27Bta_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_aqgffqYw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_qfxjXowA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_s1XSHEup, HV_BINOP_POW, 0, m, &cBinop_s1XSHEup_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_s1XSHEup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_efXXZRRJ, 0, m, &cIf_efXXZRRJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w9xzdJrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_1I11eoXK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gO1stpto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tLdiLHW1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_58koXsGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kZ8bjkKe, 0, m, &cIf_kZ8bjkKe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tLdiLHW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kZ8bjkKe, 1, m, &cIf_kZ8bjkKe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aqgffqYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_w9xzdJrF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cHA27Bta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_efXXZRRJ, 0, m, &cIf_efXXZRRJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1I11eoXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s1XSHEup, HV_BINOP_POW, 1, m, &cBinop_s1XSHEup_sendMessage);
  cMsg_qfxjXowA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_efXXZRRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_CwgoX2NB, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_Jh8CJMR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wR5kyO3r, 1, m, &cIf_wR5kyO3r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qOOFPJ6F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gNBzQTIc, HV_BINOP_GREATER_THAN, 1, m, &cBinop_gNBzQTIc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_stChHt7R, HV_BINOP_EQ, 1, m, &cBinop_stChHt7R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HSAQT6Xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tmPsvY1w, HV_BINOP_ADD, 0, m, &cBinop_tmPsvY1w_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tmPsvY1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gO1stpto_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_58koXsGp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gNBzQTIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_efXXZRRJ, 1, m, &cIf_efXXZRRJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_stChHt7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TWNBOmxg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_TWNBOmxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CwgoX2NB, m);
}

void Heavy_WSTD_DL3Y::cCast_map1CqTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HSAQT6Xr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_yNxGvrlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qxFLug7l, 0, m, &cVar_qxFLug7l_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8CVs7rMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tmPsvY1w, HV_BINOP_ADD, 1, m, &cBinop_tmPsvY1w_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gNBzQTIc, HV_BINOP_GREATER_THAN, 0, m, &cBinop_gNBzQTIc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_stChHt7R, HV_BINOP_EQ, 0, m, &cBinop_stChHt7R_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_48eX9l3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Nk6SXYYA, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_4T49Dp0A_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gYwmVjp3, 0, m, &cSlice_gYwmVjp3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oIxeUoLC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_gYwmVjp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ck3BWkp2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ck3BWkp2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_nBdXZ5fK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ck3BWkp2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ck3BWkp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZgUQ0Wq6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_oIxeUoLC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_15cW60kw, 0, m, &cSlice_15cW60kw_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bT9cw7FY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_15cW60kw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_P2JbxgkF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_P2JbxgkF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_rGCgnthK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_P2JbxgkF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_P2JbxgkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wzNu8L86_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_O2O1eMYt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6JO07H2V, 0, m, &cSlice_6JO07H2V_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XtLx6Ihs_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_6JO07H2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_v5Qo0uCj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_v5Qo0uCj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_CrrXzfju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_v5Qo0uCj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_v5Qo0uCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jnwO4YA0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_XtLx6Ihs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_P25H0vcG, 0, m, &cSlice_P25H0vcG_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_P25H0vcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lCWm3h8U_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lCWm3h8U_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_svKJDjUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lCWm3h8U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_lCWm3h8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_g1HkUfYg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_CmCbxNMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2MpiT648, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_PRWle2JJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ihxa2Dt4, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UrXXxpSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TUotKkqF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_g8PS3wTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Sjv4u47u, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_J1sfWwlf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MvM3pL8B, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_XYdY8O9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_J24osmtJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_J24osmtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FJcLy8d1, HV_BINOP_DIVIDE, 1, m, &cBinop_FJcLy8d1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HY8LqmJb_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_pklV2aU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_SsvrEaUc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gvgkKdTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_pklV2aU1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SsvrEaUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FJcLy8d1, HV_BINOP_DIVIDE, 0, m, &cBinop_FJcLy8d1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HY8LqmJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gvgkKdTk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FJcLy8d1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wpkHW1g6, HV_BINOP_MULTIPLY, 1, m, &cBinop_wpkHW1g6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wpkHW1g6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v6FtStpG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OTRRlJXz_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_qRDJf1mH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IdgroO1w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_nsSwYUiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dZ03SQOU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Vnqx4HVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_PXLM7GK9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PXLM7GK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wpkHW1g6, HV_BINOP_MULTIPLY, 0, m, &cBinop_wpkHW1g6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yeL4ShJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_RnDg16Ma_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RnDg16Ma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F7CjZfG4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gMTo3rOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ReOWPeCj, 1, m, &cVar_ReOWPeCj_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ReOWPeCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NB1yxB6G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_sQsKZL2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8OcXmqEZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_8OcXmqEZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NTd1kT7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sQsKZL2Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aUl2QcZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_hkXRjOBT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hkXRjOBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FfDUSg6I, HV_BINOP_MULTIPLY, 1, m, &cBinop_FfDUSg6I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fNKYa7A5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vrakOLhQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_vrakOLhQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QpEfikp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_fNKYa7A5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4VKsnRYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YEVffZHg, HV_BINOP_MULTIPLY, 1, m, &cBinop_YEVffZHg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tXDRoGEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KKwtGcdB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KKwtGcdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DmfPEa95, HV_BINOP_MULTIPLY, 1, m, &cBinop_DmfPEa95_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_wKppoZJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MZo4GqrH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Vnqx4HVL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9UUEoZ7Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_04okwKye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_yeL4ShJc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OTRRlJXz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_nsSwYUiS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_v6FtStpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_qRDJf1mH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_IdgroO1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7PR2ebK4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_dZ03SQOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5eiemZrp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_9YV7UrMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SqzbEjA0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_F7CjZfG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1w6OvVBq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1w6OvVBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gvbEwwaR, HV_BINOP_MULTIPLY, 1, m, &cBinop_gvbEwwaR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gvbEwwaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_camU5ozI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_camU5ozI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9YV7UrMq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_NB1yxB6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Ft3yFNa0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ft3yFNa0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PvuWW7Ci_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iYkUvJ2V_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Pl77mqWA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FX4fA2O5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_78JyXLvY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MOjhnH2N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8OcXmqEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CmCbxNMn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FfDUSg6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PRWle2JJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vrakOLhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UrXXxpSd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YEVffZHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g8PS3wTl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DmfPEa95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J1sfWwlf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_TKLBVHFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wKppoZJP, 0, m, &cVar_wKppoZJP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CMR4QdrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_04okwKye, 1, m, &cVar_04okwKye_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Pl77mqWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YEVffZHg, HV_BINOP_MULTIPLY, 0, m, &cBinop_YEVffZHg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PvuWW7Ci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_MOjhnH2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8OcXmqEZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_8OcXmqEZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iYkUvJ2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DmfPEa95, HV_BINOP_MULTIPLY, 0, m, &cBinop_DmfPEa95_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FX4fA2O5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vrakOLhQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_vrakOLhQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_78JyXLvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FfDUSg6I, HV_BINOP_MULTIPLY, 0, m, &cBinop_FfDUSg6I_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9UUEoZ7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ReOWPeCj, 0, m, &cVar_ReOWPeCj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MZo4GqrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_04okwKye, 0, m, &cVar_04okwKye_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uOFLfYWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_et17LT5F, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_hZr6n6mR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VA5rFCuh, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_QrumyD09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_duLQELrS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_vKy6r0Em_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oGOZKPio, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_BC9D6mns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RC5D5TK9_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_RC5D5TK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G2FVd3ms, HV_BINOP_DIVIDE, 1, m, &cBinop_G2FVd3ms_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Luy9MiAT_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_ZvwRZTNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_0IHNavQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tcUxXnqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ZvwRZTNr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0IHNavQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G2FVd3ms, HV_BINOP_DIVIDE, 0, m, &cBinop_G2FVd3ms_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Luy9MiAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tcUxXnqQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_G2FVd3ms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vfkkWc0B, HV_BINOP_MULTIPLY, 1, m, &cBinop_vfkkWc0B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vfkkWc0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D2aay9M3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jfONTxah_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_J5B3g4UT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6yCFKmoX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_sypeB13r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_z3n3xtJb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_0OcYQNlQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_fgF40Xqy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fgF40Xqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vfkkWc0B, HV_BINOP_MULTIPLY, 0, m, &cBinop_vfkkWc0B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_y9guxR8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_o7xhhcFE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o7xhhcFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q0U78Iq1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mSkT8X3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JXIaCMyu, HV_BINOP_MULTIPLY, 1, m, &cBinop_JXIaCMyu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KN7aSwnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4yY3n3xu, 1, m, &cVar_4yY3n3xu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TCp5lQ4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FvZTRlo8, HV_BINOP_MULTIPLY, 1, m, &cBinop_FvZTRlo8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zA1kwHvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_z6v5Jwkw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z6v5Jwkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0geHGp4W, HV_BINOP_MULTIPLY, 1, m, &cBinop_0geHGp4W_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_4yY3n3xu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Ci4F1rK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_eYQcZ6MQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fvjRn9cG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_0OcYQNlQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BycnKTL7_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Uwi0PLDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_y9guxR8o_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jfONTxah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_sypeB13r_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_D2aay9M3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_J5B3g4UT_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_6yCFKmoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hscY8OiO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_z3n3xtJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Fl5w11gv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_76UXwo1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tZIfJMs2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Q0U78Iq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_THGVA0mb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_THGVA0mb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vU7zvt1z, HV_BINOP_MULTIPLY, 1, m, &cBinop_vU7zvt1z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vU7zvt1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gsO9cGZd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gsO9cGZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_76UXwo1H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_5Ci4F1rK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zya1i1sL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zya1i1sL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JgjMHHsI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_57DGk3tp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yuyQWdp3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I2EkMcpK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Kje2wcjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uOFLfYWj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JXIaCMyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hZr6n6mR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FvZTRlo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QrumyD09_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_0geHGp4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vKy6r0Em_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ScXZYEgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eYQcZ6MQ, 0, m, &cVar_eYQcZ6MQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qcAyJaRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Uwi0PLDh, 1, m, &cVar_Uwi0PLDh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BycnKTL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4yY3n3xu, 0, m, &cVar_4yY3n3xu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fvjRn9cG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Uwi0PLDh, 0, m, &cVar_Uwi0PLDh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_57DGk3tp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FvZTRlo8, HV_BINOP_MULTIPLY, 0, m, &cBinop_FvZTRlo8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JgjMHHsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0geHGp4W, HV_BINOP_MULTIPLY, 0, m, &cBinop_0geHGp4W_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_I2EkMcpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kje2wcjo, HV_BINOP_MULTIPLY, 0, m, &cBinop_Kje2wcjo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yuyQWdp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JXIaCMyu, HV_BINOP_MULTIPLY, 0, m, &cBinop_JXIaCMyu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yoYBa7Ly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Mk7UQMb3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UkPxCvYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vd3GWE4x, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8eSiPn0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MML8y9Wb, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_r3PsHKEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4ap6Fpn7, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_AjfX1RCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_w1AuIthx, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_SJd5bmDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ale7d5En_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ale7d5En_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hemEosHF, HV_BINOP_DIVIDE, 1, m, &cBinop_hemEosHF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jg3VjUwy_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_b7tTKOq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_vB5V8sQP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4bDUJPW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_b7tTKOq4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vB5V8sQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hemEosHF, HV_BINOP_DIVIDE, 0, m, &cBinop_hemEosHF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Jg3VjUwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4bDUJPW4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hemEosHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K61unuU4, HV_BINOP_MULTIPLY, 1, m, &cBinop_K61unuU4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_K61unuU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OsJQD3Lo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3jDzDHgM_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_NpD9y9Y4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wrBNgpw4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_rgyvlayz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Dos49UYi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KQfHkvlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_NOSbxt8K_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NOSbxt8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K61unuU4, HV_BINOP_MULTIPLY, 0, m, &cBinop_K61unuU4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_G7ArFfsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_9pyGUDKs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9pyGUDKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AJsu1FBB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bv9MPPK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SATJtXJ7, HV_BINOP_MULTIPLY, 1, m, &cBinop_SATJtXJ7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ohdKX5Gf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rNFb150i_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rNFb150i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bv9MPPK4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_s3tkvDQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YoR6gpuN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YoR6gpuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MxerDJkg, HV_BINOP_MULTIPLY, 1, m, &cBinop_MxerDJkg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8o4D0ebO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IM3dX9Zs, HV_BINOP_MULTIPLY, 1, m, &cBinop_IM3dX9Zs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KQcFtpeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nFZqMqNK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nFZqMqNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8o4D0ebO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jv5VyWOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZIKsMCEZ, 1, m, &cVar_ZIKsMCEZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NakwQqQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c9dv6ELg, HV_BINOP_MULTIPLY, 1, m, &cBinop_c9dv6ELg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tRi8jbEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SMe0GoMR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SMe0GoMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vB0MZajK, HV_BINOP_MULTIPLY, 1, m, &cBinop_vB0MZajK_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ZIKsMCEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1zy5qEcD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_cfBvbOuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CJJaeYBI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_KQfHkvlR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TqwirHrf_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_dmQYvNHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_G7ArFfsM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OsJQD3Lo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_NpD9y9Y4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3jDzDHgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_rgyvlayz_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_wrBNgpw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2Zrd1yCY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Dos49UYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nTN11LpY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_FUY8i9LX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fsPHLeeF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_AJsu1FBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8sYcOugk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8sYcOugk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fcmBqiwr, HV_BINOP_MULTIPLY, 1, m, &cBinop_fcmBqiwr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fcmBqiwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Ufnse2wH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ufnse2wH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FUY8i9LX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_1zy5qEcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zcbioEZp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zcbioEZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VfKDtVDk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jPEqIZHF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OTDHsTjg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F7m8Dt1a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0NbxNTH0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IjI0E6SL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SATJtXJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yoYBa7Ly_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_MxerDJkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UkPxCvYP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IM3dX9Zs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8eSiPn0k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_c9dv6ELg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r3PsHKEZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vB0MZajK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AjfX1RCf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_i5luA7kv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cfBvbOuF, 0, m, &cVar_cfBvbOuF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8IxT9bRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dmQYvNHp, 1, m, &cVar_dmQYvNHp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_F7m8Dt1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IM3dX9Zs, HV_BINOP_MULTIPLY, 0, m, &cBinop_IM3dX9Zs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jPEqIZHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vB0MZajK, HV_BINOP_MULTIPLY, 0, m, &cBinop_vB0MZajK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IjI0E6SL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SATJtXJ7, HV_BINOP_MULTIPLY, 0, m, &cBinop_SATJtXJ7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0NbxNTH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MxerDJkg, HV_BINOP_MULTIPLY, 0, m, &cBinop_MxerDJkg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VfKDtVDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_OTDHsTjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c9dv6ELg, HV_BINOP_MULTIPLY, 0, m, &cBinop_c9dv6ELg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CJJaeYBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dmQYvNHp, 0, m, &cVar_dmQYvNHp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TqwirHrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZIKsMCEZ, 0, m, &cVar_ZIKsMCEZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wpMJGVR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_48eX9l3J, 1, m, &cIf_48eX9l3J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lyeMtQ2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Nk6SXYYA, m);
}

void Heavy_WSTD_DL3Y::cBinop_BZQTYaT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lyeMtQ2C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Qgukjqdx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_48eX9l3J, 0, m, &cIf_48eX9l3J_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_oNW1HfvP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1qIhkj29, 0, m, &cSlice_1qIhkj29_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dUhp4eob_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_1qIhkj29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AnZHljrh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AnZHljrh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_7ebw265P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AnZHljrh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_AnZHljrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gi8SkX4B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Bd10jSk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_l0nQU4N2_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_nDq3BAqE, 0, m, &cIf_nDq3BAqE_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_nDq3BAqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_66uWUnXI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_fg5ocyMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_f8T1haJ4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Hx6zrCuc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_kYU0fDEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UVvUkd3W, HV_BINOP_POW, 0, m, &cBinop_UVvUkd3W_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UVvUkd3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wnfK5Tl5, 0, m, &cIf_wnfK5Tl5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KEUX44nR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Dw3LtK77_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HzUn7GyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZQO327Ni_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_11Kat4KH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fg5ocyMB, 0, m, &cIf_fg5ocyMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZQO327Ni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fg5ocyMB, 1, m, &cIf_fg5ocyMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Hx6zrCuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_KEUX44nR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f8T1haJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_wnfK5Tl5, 0, m, &cIf_wnfK5Tl5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Dw3LtK77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UVvUkd3W, HV_BINOP_POW, 1, m, &cBinop_UVvUkd3W_sendMessage);
  cMsg_kYU0fDEu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_wnfK5Tl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_VCrWoiaz, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_l0nQU4N2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nDq3BAqE, 1, m, &cIf_nDq3BAqE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_66uWUnXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8SXgn7hd, HV_BINOP_GREATER_THAN, 1, m, &cBinop_8SXgn7hd_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jBOmEqSC, HV_BINOP_EQ, 1, m, &cBinop_jBOmEqSC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9Cb0YCqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_B8g7gm4V, HV_BINOP_ADD, 0, m, &cBinop_B8g7gm4V_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B8g7gm4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HzUn7GyT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_11Kat4KH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8SXgn7hd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wnfK5Tl5, 1, m, &cIf_wnfK5Tl5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jBOmEqSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j6YNI41S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_j6YNI41S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_VCrWoiaz, m);
}

void Heavy_WSTD_DL3Y::cCast_ozCIBWnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B8g7gm4V, HV_BINOP_ADD, 1, m, &cBinop_B8g7gm4V_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8SXgn7hd, HV_BINOP_GREATER_THAN, 0, m, &cBinop_8SXgn7hd_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jBOmEqSC, HV_BINOP_EQ, 0, m, &cBinop_jBOmEqSC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7bLlDhlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9Cb0YCqt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_mcs0DOOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Bd10jSk9, 0, m, &cVar_Bd10jSk9_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_QNEQxQkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_69z8p1zn_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_VXKWz8hM, 0, m, &cIf_VXKWz8hM_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_VXKWz8hM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jqZ4SUIK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_sOYhfo44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_jCnz6LVS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_u9Ws8buF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_W86TvW6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BmIqToWE, HV_BINOP_POW, 0, m, &cBinop_BmIqToWE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BmIqToWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JGXaFqQy, 0, m, &cIf_JGXaFqQy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2pxedAlK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_kg1sEZEV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KKNZpEZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sOYhfo44, 0, m, &cIf_sOYhfo44_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nnYnf9dE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8qN5t2Q9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8qN5t2Q9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sOYhfo44, 1, m, &cIf_sOYhfo44_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u9Ws8buF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_2pxedAlK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jCnz6LVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_JGXaFqQy, 0, m, &cIf_JGXaFqQy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kg1sEZEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BmIqToWE, HV_BINOP_POW, 1, m, &cBinop_BmIqToWE_sendMessage);
  cMsg_W86TvW6n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_JGXaFqQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CWNyIVlc_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NtaLsRAb_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_fgRdSdOy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_69z8p1zn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VXKWz8hM, 1, m, &cIf_VXKWz8hM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jqZ4SUIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kv3ENKJI, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Kv3ENKJI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2pB748q8, HV_BINOP_EQ, 1, m, &cBinop_2pB748q8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RCogh2Yb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zbhanzsb, HV_BINOP_ADD, 0, m, &cBinop_Zbhanzsb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Zbhanzsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nnYnf9dE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KKNZpEZC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Kv3ENKJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JGXaFqQy, 1, m, &cIf_JGXaFqQy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2pB748q8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mDNkukkc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_mDNkukkc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CWNyIVlc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NtaLsRAb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_fgRdSdOy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oN8lEQNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RCogh2Yb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_SqDyEq0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zbhanzsb, HV_BINOP_ADD, 1, m, &cBinop_Zbhanzsb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kv3ENKJI, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Kv3ENKJI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2pB748q8, HV_BINOP_EQ, 0, m, &cBinop_2pB748q8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_N57B1y0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QNEQxQkp, 0, m, &cVar_QNEQxQkp_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_R1tZj1hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4IOVbpv0_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_wJJq0goy, 0, m, &cIf_wJJq0goy_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_wJJq0goy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FeLrFw6z_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_K8AGfv5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_NHDqgje8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Gy5TD8ie_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_o44qDVGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dH8FjgLZ, HV_BINOP_POW, 0, m, &cBinop_dH8FjgLZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dH8FjgLZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_quSYb07m, 0, m, &cIf_quSYb07m_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EdceWpKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_efa4kIWk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zyGRRdpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K8AGfv5Z, 0, m, &cIf_K8AGfv5Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HlRCPqE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5M10ze9E_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5M10ze9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K8AGfv5Z, 1, m, &cIf_K8AGfv5Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Gy5TD8ie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_EdceWpKq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NHDqgje8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_quSYb07m, 0, m, &cIf_quSYb07m_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_efa4kIWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dH8FjgLZ, HV_BINOP_POW, 1, m, &cBinop_dH8FjgLZ_sendMessage);
  cMsg_o44qDVGl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_quSYb07m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Xllp4blt, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_4IOVbpv0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wJJq0goy, 1, m, &cIf_wJJq0goy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FeLrFw6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kaz5VU2y, HV_BINOP_GREATER_THAN, 1, m, &cBinop_kaz5VU2y_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NFp2A1j7, HV_BINOP_EQ, 1, m, &cBinop_NFp2A1j7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NVG8NQyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAR3sQli, HV_BINOP_ADD, 0, m, &cBinop_xAR3sQli_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xAR3sQli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HlRCPqE6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zyGRRdpD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kaz5VU2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_quSYb07m, 1, m, &cIf_quSYb07m_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NFp2A1j7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZCa9wtNc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_ZCa9wtNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Xllp4blt, m);
}

void Heavy_WSTD_DL3Y::cCast_7g0IHiED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAR3sQli, HV_BINOP_ADD, 1, m, &cBinop_xAR3sQli_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_kaz5VU2y, HV_BINOP_GREATER_THAN, 0, m, &cBinop_kaz5VU2y_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NFp2A1j7, HV_BINOP_EQ, 0, m, &cBinop_NFp2A1j7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_v7cnT5w9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R1tZj1hy, 0, m, &cVar_R1tZj1hy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KZGd477j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NVG8NQyG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_A6fjV44P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_0uyzyeYp, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_UfjqCsaI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_p4SQ44v1, 0, m, &cSlice_p4SQ44v1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2LMz6vj5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_p4SQ44v1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PoAMg8vU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PoAMg8vU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_tz5Wrkie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PoAMg8vU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_PoAMg8vU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HLYu0QzR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_2LMz6vj5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_13wGXgH7, 0, m, &cSlice_13wGXgH7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oNW1HfvP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_13wGXgH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rwZ0Bu81_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rwZ0Bu81_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_jnR0RceH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rwZ0Bu81_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_rwZ0Bu81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iAC0IYzS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_dUhp4eob_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kQ04dGRT, 0, m, &cSlice_kQ04dGRT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Rpxj2cVg_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_kQ04dGRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5eLOl5hj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5eLOl5hj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_lAoPmes5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5eLOl5hj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_5eLOl5hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VFLY7H80_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Rpxj2cVg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_I1VtcSl6, 0, m, &cSlice_I1VtcSl6_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_I1VtcSl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xkuKRYwO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xkuKRYwO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_QxXlFph3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xkuKRYwO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_xkuKRYwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uOYIvocj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_ijyUOHn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dmZzR6wY, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_9Zi0R7GZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r9XBIiK9, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_uOzNOr3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NQ1qTYDh, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tEd6WELA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2WifDiJS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Z01VDoEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_14KH4T7T, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_OZo8znFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IE2AEFOH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_IE2AEFOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4ypkrLjS, HV_BINOP_DIVIDE, 1, m, &cBinop_4ypkrLjS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NUGZ8EbV_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_EsJXB68v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_7tLJXQBx_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CvzMezes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_EsJXB68v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7tLJXQBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4ypkrLjS, HV_BINOP_DIVIDE, 0, m, &cBinop_4ypkrLjS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NUGZ8EbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CvzMezes_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4ypkrLjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DQu62pMg, HV_BINOP_MULTIPLY, 1, m, &cBinop_DQu62pMg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DQu62pMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OBtSvqoM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EHkKzxKg_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_loAkeVkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zkrYTzTE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_WRRr4dyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_b24ascVC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_J1WYdycR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_QgFhHkao_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QgFhHkao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DQu62pMg, HV_BINOP_MULTIPLY, 0, m, &cBinop_DQu62pMg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sw5CNrZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Rt65a87Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Rt65a87Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jKK64IQa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_jT7R54Nl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IIu05yFw, 1, m, &cVar_IIu05yFw_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_IIu05yFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mjnuy6En_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_W3uZeJJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wsLbeHHq, HV_BINOP_MULTIPLY, 1, m, &cBinop_wsLbeHHq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_E5FAc3Gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_W3uZeJJl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3ekTlkIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jn810jwe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jn810jwe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q0UiXzla, HV_BINOP_MULTIPLY, 1, m, &cBinop_Q0UiXzla_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Wrwp2uXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9rIcyZ2K, HV_BINOP_MULTIPLY, 1, m, &cBinop_9rIcyZ2K_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nkQWjBYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Wrwp2uXS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_m81xvBGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4HC27nVh, HV_BINOP_MULTIPLY, 1, m, &cBinop_4HC27nVh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PHQHMSQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uhN13SXI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uhN13SXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U2whlAyt, HV_BINOP_MULTIPLY, 1, m, &cBinop_U2whlAyt_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_zcs1Z90u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2VupeJUo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_J1WYdycR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pdvfNLYb_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_atF22fW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_sw5CNrZL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EHkKzxKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_WRRr4dyK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OBtSvqoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_loAkeVkM_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_zkrYTzTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UT2rYG8C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_b24ascVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xNOpJCkj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ekmRaoGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EzkjrWnQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_jKK64IQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8hZNCrj0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8hZNCrj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U9ywQ3MA, HV_BINOP_MULTIPLY, 1, m, &cBinop_U9ywQ3MA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U9ywQ3MA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Ecxs43mF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ecxs43mF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ekmRaoGO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_mjnuy6En_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_UWE9QMDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UWE9QMDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BcrUdkyQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hyMgh0VB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OW4laS0D_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rlBstUvF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1yGKEJNZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QsI4wv3G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wsLbeHHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ijyUOHn0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Q0UiXzla_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9Zi0R7GZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9rIcyZ2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uOzNOr3p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4HC27nVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tEd6WELA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_U2whlAyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z01VDoEH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_VZVIzKQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zcs1Z90u, 0, m, &cVar_zcs1Z90u_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hInutlCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_atF22fW4, 1, m, &cVar_atF22fW4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OW4laS0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4HC27nVh, HV_BINOP_MULTIPLY, 0, m, &cBinop_4HC27nVh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1yGKEJNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q0UiXzla, HV_BINOP_MULTIPLY, 0, m, &cBinop_Q0UiXzla_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hyMgh0VB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U2whlAyt, HV_BINOP_MULTIPLY, 0, m, &cBinop_U2whlAyt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BcrUdkyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_QsI4wv3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wsLbeHHq, HV_BINOP_MULTIPLY, 0, m, &cBinop_wsLbeHHq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rlBstUvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9rIcyZ2K, HV_BINOP_MULTIPLY, 0, m, &cBinop_9rIcyZ2K_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2VupeJUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_atF22fW4, 0, m, &cVar_atF22fW4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pdvfNLYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IIu05yFw, 0, m, &cVar_IIu05yFw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DeJBTNng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qJkLsPcl, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qkwG77Uo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3DKRGW5S, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ySryYuPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PIUYuG98, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_D69Ru3Yw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rwdCeEGJ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_oImdtuwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7h8X6rf8_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_7h8X6rf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j55lZtFG, HV_BINOP_DIVIDE, 1, m, &cBinop_j55lZtFG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AluWDPb8_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_oGROTolc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_t5X004ia_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_raENOEwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_oGROTolc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t5X004ia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j55lZtFG, HV_BINOP_DIVIDE, 0, m, &cBinop_j55lZtFG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AluWDPb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_raENOEwm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_j55lZtFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SNQyKrTY, HV_BINOP_MULTIPLY, 1, m, &cBinop_SNQyKrTY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SNQyKrTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mcoz2JSP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D5FLiwIG_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_i9aHMiPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ufdpiT6C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_QuKlhdXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iv83Kpyf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_16a2RIyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_hAuI0jHX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hAuI0jHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SNQyKrTY, HV_BINOP_MULTIPLY, 0, m, &cBinop_SNQyKrTY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lHvT8XVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_B9oANY9K_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B9oANY9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vjOIkzeo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fNecWXsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YIkeTgY4, HV_BINOP_MULTIPLY, 1, m, &cBinop_YIkeTgY4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rhi9nxns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8cB9JSBM, 1, m, &cVar_8cB9JSBM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_K8UefCAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J2gr0kST, HV_BINOP_MULTIPLY, 1, m, &cBinop_J2gr0kST_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_d4fINlKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_evz1MuKL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_evz1MuKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o6v6y7Ab, HV_BINOP_MULTIPLY, 1, m, &cBinop_o6v6y7Ab_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_8cB9JSBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OdBk1Rru_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_4JIAjRFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mle23cT6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_16a2RIyB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z1gAjZcX_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_LJu5p3Dg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_lHvT8XVq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_D5FLiwIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_QuKlhdXX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Mcoz2JSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_i9aHMiPj_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_ufdpiT6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VrMcHY7K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_iv83Kpyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qh5w0bMW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_uMeBoUvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5Z7pifbR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_vjOIkzeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ALWwynZm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ALWwynZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dkwrDPPP, HV_BINOP_MULTIPLY, 1, m, &cBinop_dkwrDPPP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dkwrDPPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NQuWk8f1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NQuWk8f1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uMeBoUvp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_OdBk1Rru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_M5KKFFgs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_M5KKFFgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3MnQ3kf4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fVIQgF7h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bO12yDyc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VgFkNFua_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3nG7CFva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DeJBTNng_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YIkeTgY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qkwG77Uo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_J2gr0kST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ySryYuPE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_o6v6y7Ab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D69Ru3Yw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_eV7iGUlh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4JIAjRFc, 0, m, &cVar_4JIAjRFc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_H9ijAUxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LJu5p3Dg, 1, m, &cVar_LJu5p3Dg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Mle23cT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LJu5p3Dg, 0, m, &cVar_LJu5p3Dg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_z1gAjZcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8cB9JSBM, 0, m, &cVar_8cB9JSBM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VgFkNFua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3nG7CFva, HV_BINOP_MULTIPLY, 0, m, &cBinop_3nG7CFva_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bO12yDyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YIkeTgY4, HV_BINOP_MULTIPLY, 0, m, &cBinop_YIkeTgY4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fVIQgF7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J2gr0kST, HV_BINOP_MULTIPLY, 0, m, &cBinop_J2gr0kST_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3MnQ3kf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o6v6y7Ab, HV_BINOP_MULTIPLY, 0, m, &cBinop_o6v6y7Ab_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Zz1l06j0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ETdqyVsQ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ZW0VgEjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ndo9TACG, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_CUkxJr3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kgF66fMt, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3eJJNlxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1VGE0G6h, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_gCBlErRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IYYCDG1p, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_9yCewEa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_m0TlTutL_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_m0TlTutL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bHNFK20p, HV_BINOP_DIVIDE, 1, m, &cBinop_bHNFK20p_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rc8scSxD_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_5NQ00csI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_AQDjdGk1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NApccAJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_5NQ00csI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AQDjdGk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bHNFK20p, HV_BINOP_DIVIDE, 0, m, &cBinop_bHNFK20p_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Rc8scSxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NApccAJ4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bHNFK20p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ams3gu6u, HV_BINOP_MULTIPLY, 1, m, &cBinop_ams3gu6u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ams3gu6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KXHjd49L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mC7mr6mr_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_wPY3FOou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nWQbtsef_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_bCK0zx6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cbYahz1q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_h4H4U5EX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_MHfsuTzA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MHfsuTzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ams3gu6u, HV_BINOP_MULTIPLY, 0, m, &cBinop_ams3gu6u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_h3HmJCfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_yQi5rvmX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yQi5rvmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fb0n7aNw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_cGxvdECs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lowz1wn1, HV_BINOP_MULTIPLY, 1, m, &cBinop_Lowz1wn1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qLYsL4xM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SHty1rco_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SHty1rco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cGxvdECs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xV5nu3DL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_GCAuLZl9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GCAuLZl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Uo4i80nV, HV_BINOP_MULTIPLY, 1, m, &cBinop_Uo4i80nV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CR4Hwgi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J6socpt4, HV_BINOP_MULTIPLY, 1, m, &cBinop_J6socpt4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_U0OBe6PK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NWjQMEFG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NWjQMEFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CR4Hwgi0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cyX5Tifd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fTwY6S7N, 1, m, &cVar_fTwY6S7N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TaZ3QR4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WCSzdCZ2, HV_BINOP_MULTIPLY, 1, m, &cBinop_WCSzdCZ2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Dk0wajA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_fVAPQC8r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fVAPQC8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PiHyuCem, HV_BINOP_MULTIPLY, 1, m, &cBinop_PiHyuCem_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_fTwY6S7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hPtIVzPf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_cK4Xxqaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w0TIdA1q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_h4H4U5EX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0964KsSb_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_lAIhn97V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_h3HmJCfc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KXHjd49L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_wPY3FOou_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mC7mr6mr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_bCK0zx6d_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_nWQbtsef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5bxpUvHx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_cbYahz1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_M2dDOz8h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_WHXucSn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9KPw4WJ4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_fb0n7aNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VpYWbId6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VpYWbId6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WF0ZfEtJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_WF0ZfEtJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WF0ZfEtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_aQox5V8f_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aQox5V8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WHXucSn3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_hPtIVzPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_12eD9Cq3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_12eD9Cq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aWaR7VuF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5QLBgBKQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jEylqv0E_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3DexnDnn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LPasAJHr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lliuo274_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Lowz1wn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zz1l06j0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Uo4i80nV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZW0VgEjB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_J6socpt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CUkxJr3Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WCSzdCZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3eJJNlxW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PiHyuCem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gCBlErRs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_MkznKm26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cK4Xxqaa, 0, m, &cVar_cK4Xxqaa_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XNhuye4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lAIhn97V, 1, m, &cVar_lAIhn97V_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Lliuo274_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lowz1wn1, HV_BINOP_MULTIPLY, 0, m, &cBinop_Lowz1wn1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LPasAJHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Uo4i80nV, HV_BINOP_MULTIPLY, 0, m, &cBinop_Uo4i80nV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aWaR7VuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_jEylqv0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WCSzdCZ2, HV_BINOP_MULTIPLY, 0, m, &cBinop_WCSzdCZ2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3DexnDnn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J6socpt4, HV_BINOP_MULTIPLY, 0, m, &cBinop_J6socpt4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5QLBgBKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PiHyuCem, HV_BINOP_MULTIPLY, 0, m, &cBinop_PiHyuCem_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0964KsSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fTwY6S7N, 0, m, &cVar_fTwY6S7N_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_w0TIdA1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lAIhn97V, 0, m, &cVar_lAIhn97V_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CWNyIVlc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A6fjV44P, 1, m, &cIf_A6fjV44P_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QVzkwX48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_0uyzyeYp, m);
}

void Heavy_WSTD_DL3Y::cBinop_NtaLsRAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QVzkwX48_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fgRdSdOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A6fjV44P, 0, m, &cIf_A6fjV44P_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_GCYDCH7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KUOL0Fjx, HV_BINOP_DIVIDE, 0, m, &cBinop_KUOL0Fjx_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_PT4GzEsn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ka5md4q2, HV_BINOP_DIVIDE, 1, m, &cBinop_Ka5md4q2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KUOL0Fjx, HV_BINOP_DIVIDE, 1, m, &cBinop_KUOL0Fjx_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_ZhhIbkqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QtYPzDh1, HV_BINOP_DIVIDE, 0, m, &cBinop_QtYPzDh1_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_oaJXuNiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QtYPzDh1, HV_BINOP_DIVIDE, 1, m, &cBinop_QtYPzDh1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jUU0DyEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PT4GzEsn, 0, m, &cVar_PT4GzEsn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_eWtoOn11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GCYDCH7K, 0, m, &cVar_GCYDCH7K_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Q8m2ueYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ka5md4q2, HV_BINOP_DIVIDE, 0, m, &cBinop_Ka5md4q2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ka5md4q2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_ZhhIbkqk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KUOL0Fjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_oaJXuNiY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QtYPzDh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_PldqfrsD_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_hIOSVPYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_hEQRkCK9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P1tK5oMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_ExKcXztG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PldqfrsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_P1tK5oMx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ExKcXztG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_hIOSVPYD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hEQRkCK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ADni1T7d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_NkvbTTvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sAaxYbgQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_kVGDrYAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c4RwmMn5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_6I8XEJ1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3r0OO8b5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_e8tgKWrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RZ6KRXPt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_eLvMGduN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IMeMu1sR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_4OZYgtIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dRUNec6p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_3M6cWgcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mZruvoqk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_oECDjVgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dfiRwytA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_vSjk6RCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6uf6guqO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Gbo0ywP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9xAWuU1S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_C7zNzSu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zv4UsHy6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_KApAWxsj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CJ2S3kMy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_h4yrtErZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wkV1Y78Y, 0, m, &cSlice_wkV1Y78Y_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_wkV1Y78Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xKz53Cyk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xKz53Cyk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_RaK3I23A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xKz53Cyk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_xKz53Cyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MvrF1fwV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_CA1fPuoq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LwEKUOYd, 0, m, &cSlice_LwEKUOYd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CD3rOUpV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_LwEKUOYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KuWc6atB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KuWc6atB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_80CZ8oDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KuWc6atB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_KuWc6atB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SZoeBqn4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_r6FONQIR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_58Rhc5BL, 0, m, &cSlice_58Rhc5BL_sendMessage);
      break;
    }
    default: {
      cSwitchcase_h4yrtErZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_58Rhc5BL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UjnX3w3M_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UjnX3w3M_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_O6lgFkxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UjnX3w3M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_UjnX3w3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Vn9IU9L4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_glJbYqxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_FT8IykPR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FT8IykPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_QgvdPLHj_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_8I8ZS9eK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PU8wf03O_sendMessage(_c, 0, m);
  cMsg_3qFYWCme_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_UsLKV4Og_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YLpNa6Ft_sendMessage(_c, 0, m);
  cMsg_sAkwjgnW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QgvdPLHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ezKZi0Pk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ezKZi0Pk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KvSlgGef_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pYIH8GEz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KvSlgGef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_G6DpgUzt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pYIH8GEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TtZz1gKE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_G6DpgUzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SHwlUOLF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TtZz1gKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ftsc5XEE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ftsc5XEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3yTM6yNV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SHwlUOLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_8I8ZS9eK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3yTM6yNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_UsLKV4Og_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_567wkRoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_wtOmVAaR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wtOmVAaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_HTdPvx8G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HTdPvx8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_JYrIXZVI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JYrIXZVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4NKuv8lh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XuT9nrFx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4NKuv8lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YkxZ3HI1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XuT9nrFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uDcKwlMd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YkxZ3HI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6G0WHg6b_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uDcKwlMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gJ3Wjwa3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gJ3Wjwa3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7zadM6Ns_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7zadM6Ns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_znygo6WB_sendMessage(_c, 0, m);
  cMsg_rHRYxaeb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6G0WHg6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oZmP6q5H_sendMessage(_c, 0, m);
  cMsg_tJPK7xPm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7NufiZV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_qff4LX8t_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qff4LX8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VqC3EhHv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_aETtUuzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_3quvafgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_NBGmaIns_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jyBfMCeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GB0i9b4V_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_GB0i9b4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tducXrGb, HV_BINOP_DIVIDE, 1, m, &cBinop_tducXrGb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VqC3EhHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_x7mWtU7C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x7mWtU7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rCnszJKm, m);
}

void Heavy_WSTD_DL3Y::cMsg_NO2zCEnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SRoeypcy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SRoeypcy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_7NufiZV8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aETtUuzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_X2bjEglF, m);
}

void Heavy_WSTD_DL3Y::cBinop_NBGmaIns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_iB2qcq7F_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iB2qcq7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tducXrGb, HV_BINOP_DIVIDE, 0, m, &cBinop_tducXrGb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tducXrGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NO2zCEnV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lqvQpczx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SJsBXhW3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SJsBXhW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YwqhF8x6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_KuXmPTCL_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_cRliIBoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_HTOHe3Z7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Q0rs2hZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_E221E6EN_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_E221E6EN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aRKamtg1, HV_BINOP_DIVIDE, 1, m, &cBinop_aRKamtg1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YwqhF8x6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qjniWX50_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qjniWX50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XsVel6Nf, m);
}

void Heavy_WSTD_DL3Y::cMsg_IScS6g5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9jbBIcha_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9jbBIcha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_lqvQpczx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KuXmPTCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ovMCqtx2, m);
}

void Heavy_WSTD_DL3Y::cBinop_HTOHe3Z7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_BRR03Xgz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BRR03Xgz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aRKamtg1, HV_BINOP_DIVIDE, 0, m, &cBinop_aRKamtg1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aRKamtg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IScS6g5v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_4NqMeyxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Ty6p4u7, HV_BINOP_MULTIPLY, 0, m, &cBinop_6Ty6p4u7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ww0hCeo4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Sp1nyOWs_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Sp1nyOWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6Z8axiPY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6Ty6p4u7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hXyWVxUD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HXXtf7yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Ty6p4u7, HV_BINOP_MULTIPLY, 1, m, &cBinop_6Ty6p4u7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6Z8axiPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_HXXtf7yo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hXyWVxUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_lAnmoeFN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lAnmoeFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_gvDX5KpK_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_F6CXE34I, m);
}

void Heavy_WSTD_DL3Y::cBinop_gvDX5KpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lVKQm5N2, m);
}

void Heavy_WSTD_DL3Y::cVar_s5ghIzpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kpDOItcE, HV_BINOP_MULTIPLY, 0, m, &cBinop_kpDOItcE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hZRaV4Ja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MdAcTLD6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_MdAcTLD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Eea3jMwk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kpDOItcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vaekmsBp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_theGg2ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kpDOItcE, HV_BINOP_MULTIPLY, 1, m, &cBinop_kpDOItcE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Eea3jMwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_theGg2ah_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vaekmsBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_PDHGOStI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PDHGOStI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_nLsjLtGS_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_O8jWdoHs, m);
}

void Heavy_WSTD_DL3Y::cBinop_nLsjLtGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GznuRjsj, m);
}

void Heavy_WSTD_DL3Y::sEnv_idzMh9sT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f24Kgonf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_73GNGtNy_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_omgSxWQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_wvxjyLr1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_FDEWJVlf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_8pmO3AD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_atTASeMl, HV_BINOP_POW, 0, m, &cBinop_atTASeMl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_atTASeMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VVOU4aBh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KrnLAjaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_tg9mPb6O_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_f24Kgonf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_antI0QYo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_73GNGtNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_omgSxWQv, 0, m, &cIf_omgSxWQv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_antI0QYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_omgSxWQv, 1, m, &cIf_omgSxWQv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FDEWJVlf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_KrnLAjaV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wvxjyLr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_VVOU4aBh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tg9mPb6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_atTASeMl, HV_BINOP_POW, 1, m, &cBinop_atTASeMl_sendMessage);
  cMsg_8pmO3AD4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_WYUqzyM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_01VpmqlK, HV_BINOP_MULTIPLY, 0, m, &cBinop_01VpmqlK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3Fe2cEz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Btul9POd_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Btul9POd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RV2mQu1d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_01VpmqlK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_8lnsmfVs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MVye7BzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_01VpmqlK, HV_BINOP_MULTIPLY, 1, m, &cBinop_01VpmqlK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RV2mQu1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MVye7BzX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8lnsmfVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_cIZoKOi9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cIZoKOi9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_GrEGO1hX_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_aHX52VRt, m);
}

void Heavy_WSTD_DL3Y::cBinop_GrEGO1hX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ivNGQ2hZ, m);
}

void Heavy_WSTD_DL3Y::cMsg_VVOU4aBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_lOosBxeu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lOosBxeu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VnNIqspL, m);
}

void Heavy_WSTD_DL3Y::sEnv_0hJNJ1CW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gtQCSIvW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M34M6ws1_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ixhMkcqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_9dsG6eO3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_5MyeggZw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_kBCm7R7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HTFuyS1Q, HV_BINOP_POW, 0, m, &cBinop_HTFuyS1Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HTFuyS1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i8tJfeg4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Slw7CXIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_2zFB7OgD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gtQCSIvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9N6jWqSJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_M34M6ws1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ixhMkcqF, 0, m, &cIf_ixhMkcqF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9N6jWqSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ixhMkcqF, 1, m, &cIf_ixhMkcqF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5MyeggZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Slw7CXIZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9dsG6eO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_i8tJfeg4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2zFB7OgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HTFuyS1Q, HV_BINOP_POW, 1, m, &cBinop_HTFuyS1Q_sendMessage);
  cMsg_kBCm7R7F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_WrJu9tF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uoSY12vu, HV_BINOP_MULTIPLY, 0, m, &cBinop_uoSY12vu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CYjfstug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CL8mHTcj_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_CL8mHTcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e6ymSHMO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_uoSY12vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_LcvMW08j_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SxGBHiy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uoSY12vu, HV_BINOP_MULTIPLY, 1, m, &cBinop_uoSY12vu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_e6ymSHMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SxGBHiy6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LcvMW08j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_5z6kw5H6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5z6kw5H6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_veFAYNZD_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ljY3vBxr, m);
}

void Heavy_WSTD_DL3Y::cBinop_veFAYNZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_S78jRPEJ, m);
}

void Heavy_WSTD_DL3Y::cMsg_i8tJfeg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LgeNiScf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LgeNiScf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_P1jV1PEO, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_CD3rOUpV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_L2EeecZh, 0, m, &cSlice_L2EeecZh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_r6FONQIR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_L2EeecZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_t8jcG5vb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_t8jcG5vb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_xfAub66P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_t8jcG5vb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_t8jcG5vb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pD2OMkmo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_60IY5otT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pzCf7cTC_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_pzCf7cTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_oNW09cZS_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_299AZzQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_299AZzQT, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_u2WI86OC, 0, m, &cDelay_u2WI86OC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_299AZzQT, 0, m, &cDelay_299AZzQT_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_oKwGIwwi, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_u2WI86OC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_u2WI86OC, m);
  cMsg_2m9P1aKa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ILDrfCOq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_VODG55jI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_aJ0AtJwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DdjDgZ6l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_ZhkXHBMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E18TFETP_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_299AZzQT, 2, m, &cDelay_299AZzQT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pGOnev6I_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DdjDgZ6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ZhkXHBMe, 0, m, &hTable_ZhkXHBMe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oNW09cZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_aJ0AtJwr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2m9P1aKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ZhkXHBMe, 0, m, &hTable_ZhkXHBMe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pGOnev6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_299AZzQT, 0, m, &cDelay_299AZzQT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_E18TFETP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_u2WI86OC, 2, m, &cDelay_u2WI86OC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VODG55jI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_oKwGIwwi, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_kKrKBgH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YYZtXYfn, HV_BINOP_SUBTRACT, 0, m, &cBinop_YYZtXYfn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jRQbJyzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mfq79e06_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_mfq79e06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_lt6zcLdX_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_x1xIkQ9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SjHaKoRR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_N9qkUCDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_N9qkUCDh, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y1vPjL64, 0, m, &cDelay_Y1vPjL64_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_BHAehiYw, 0, m, &sTabread_BHAehiYw_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_Y1vPjL64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y1vPjL64, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_BHAehiYw, 0, m, &sTabread_BHAehiYw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y1vPjL64, 0, m, &cDelay_Y1vPjL64_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_BHAehiYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_mN8SHJIn, HV_BINOP_SUBTRACT, 0, m, &cBinop_mN8SHJIn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_Mliwy4jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZrchINVr, HV_BINOP_MAX, 0, m, &cBinop_ZrchINVr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lt6zcLdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mliwy4jo, HV_BINOP_MULTIPLY, 0, m, &cBinop_Mliwy4jo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YYZtXYfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PPd36geu_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_BHAehiYw, 0, m, &sTabread_BHAehiYw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v8Unf0WL_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_tyvgQrV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mN8SHJIn, HV_BINOP_SUBTRACT, 1, m, &cBinop_mN8SHJIn_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y1vPjL64, 2, m, &cDelay_Y1vPjL64_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SjHaKoRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tyvgQrV4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PPd36geu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_N9qkUCDh, 0, m, &cDelay_N9qkUCDh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y1vPjL64, 0, m, &cDelay_Y1vPjL64_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yV3xrgzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZrchINVr, HV_BINOP_MAX, 1, m, &cBinop_ZrchINVr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZrchINVr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YYZtXYfn, HV_BINOP_SUBTRACT, 1, m, &cBinop_YYZtXYfn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_v8Unf0WL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_N9qkUCDh, 0, m, &cDelay_N9qkUCDh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kq7LS4zG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_N9qkUCDh, 2, m, &cDelay_N9qkUCDh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mN8SHJIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kq7LS4zG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ypy8S1Mv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x1xIkQ9p, 0, m, &cVar_x1xIkQ9p_sendMessage);
  cMsg_jRQbJyzI_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_kKrKBgH0, 0, m, &cTabhead_kKrKBgH0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_k2cHubtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fAGDBswo_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_fAGDBswo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_S8ku0zZ7_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_IZlrPGwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IZlrPGwf, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lWgEp5Qh, 0, m, &cDelay_lWgEp5Qh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IZlrPGwf, 0, m, &cDelay_IZlrPGwf_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PgfyetM3, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_lWgEp5Qh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lWgEp5Qh, m);
  cMsg_BFZRdYoN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_XevQP7a7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_TMaQA6bi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_djdxD746_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q9hilHxN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_QVsziLM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D1H7SHa4_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IZlrPGwf, 2, m, &cDelay_IZlrPGwf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lpViMVdo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_q9hilHxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_QVsziLM8, 0, m, &hTable_QVsziLM8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_S8ku0zZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_djdxD746_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BFZRdYoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_QVsziLM8, 0, m, &hTable_QVsziLM8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lpViMVdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IZlrPGwf, 0, m, &cDelay_IZlrPGwf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_D1H7SHa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_lWgEp5Qh, 2, m, &cDelay_lWgEp5Qh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TMaQA6bi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PgfyetM3, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_RnQiAKn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lBamZ0ym, HV_BINOP_SUBTRACT, 0, m, &cBinop_lBamZ0ym_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_h6I1OXCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IwfyKf0r_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_IwfyKf0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9wRTc6Bq_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_sRmzWkhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wPCb7sOB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_Xl8fiUHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Xl8fiUHt, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yG3zcDJA, 0, m, &cDelay_yG3zcDJA_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_9DhyWZe9, 0, m, &sTabread_9DhyWZe9_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_yG3zcDJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yG3zcDJA, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_9DhyWZe9, 0, m, &sTabread_9DhyWZe9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yG3zcDJA, 0, m, &cDelay_yG3zcDJA_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_9DhyWZe9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_KXW7vv0w, HV_BINOP_SUBTRACT, 0, m, &cBinop_KXW7vv0w_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_5wQqil91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VJIQL4LX, HV_BINOP_MAX, 0, m, &cBinop_VJIQL4LX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9wRTc6Bq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5wQqil91, HV_BINOP_MULTIPLY, 0, m, &cBinop_5wQqil91_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lBamZ0ym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kzhGhqG6_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_9DhyWZe9, 0, m, &sTabread_9DhyWZe9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2YPUK7lh_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Crj5NylR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KXW7vv0w, HV_BINOP_SUBTRACT, 1, m, &cBinop_KXW7vv0w_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yG3zcDJA, 2, m, &cDelay_yG3zcDJA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wPCb7sOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Crj5NylR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kzhGhqG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xl8fiUHt, 0, m, &cDelay_Xl8fiUHt_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_yG3zcDJA, 0, m, &cDelay_yG3zcDJA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TfFjMlrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_VJIQL4LX, HV_BINOP_MAX, 1, m, &cBinop_VJIQL4LX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VJIQL4LX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lBamZ0ym, HV_BINOP_SUBTRACT, 1, m, &cBinop_lBamZ0ym_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2YPUK7lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xl8fiUHt, 0, m, &cDelay_Xl8fiUHt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_j6hic8rB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Xl8fiUHt, 2, m, &cDelay_Xl8fiUHt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KXW7vv0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_j6hic8rB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nX71wbx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sRmzWkhF, 0, m, &cVar_sRmzWkhF_sendMessage);
  cMsg_h6I1OXCQ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_RnQiAKn2, 0, m, &cTabhead_RnQiAKn2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PU8wf03O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2z4p89yi, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_YLpNa6Ft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L9wy0SbF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_sAkwjgnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Rtwni67f, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3qFYWCme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f0gejDFD, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tJPK7xPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TnYRHVyD, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_znygo6WB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_O7OuF9HX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_oZmP6q5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cCE8JiVQ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_rHRYxaeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X7pWH3wy, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_nttvB3Ky_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_f3sbJEKH, 0, m, &cSlice_f3sbJEKH_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_f3sbJEKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vYEDCmkn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vYEDCmkn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_qNJC89rL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vYEDCmkn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_vYEDCmkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TBPSKCeb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_v27LEz6c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rqvb7z54, 0, m, &cSlice_rqvb7z54_sendMessage);
      break;
    }
    default: {
      cSwitchcase_d0ofmHMh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_rqvb7z54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_y9tHbA5p_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_y9tHbA5p_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Xi511yDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_y9tHbA5p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_y9tHbA5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_K5PK4Gby_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_5ThdbTp0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vD5WvQfk, 0, m, &cSlice_vD5WvQfk_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nttvB3Ky_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_vD5WvQfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KEhGi8Bp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KEhGi8Bp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_lK6nCmOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KEhGi8Bp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_KEhGi8Bp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RqtNdhU4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2wo0kVZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gjlkumbi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gjlkumbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_LTaRNcwT_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_0nplAtsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ACsVug9u_sendMessage(_c, 0, m);
  cMsg_qPWRIbST_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_2zERbRlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YiWc5LFX_sendMessage(_c, 0, m);
  cMsg_nXpN2kad_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LTaRNcwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_VoZcob6I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VoZcob6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9li1TD5n_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5cszFg4v_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9li1TD5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9nJBejsl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5cszFg4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TEnf8SLj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9nJBejsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Bf3ycSvJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TEnf8SLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_t2QtD8qm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t2QtD8qm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7ZSd9CKo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Bf3ycSvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_0nplAtsX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7ZSd9CKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_2zERbRlp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_K8D5EhQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8RjjYDIS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8RjjYDIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_d08NaOsf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d08NaOsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_gYftwSsn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gYftwSsn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Kq13Kuyh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NgiUru06_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NgiUru06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PranctcE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Kq13Kuyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_iWlbXIoo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iWlbXIoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vFujdaag_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PranctcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Oajac9GL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Oajac9GL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MzBlyqnk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MzBlyqnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FLTe5yzG_sendMessage(_c, 0, m);
  cMsg_Ty6KEUYI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vFujdaag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nHqThnA1_sendMessage(_c, 0, m);
  cMsg_SncsQ6nO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_0pPRRzfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yyb2ve4J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yyb2ve4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_HXwmhuNi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CuqLPobR_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_3kSN98pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_eFFc8gXa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8bMqbcav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QIrVtaYt_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_QIrVtaYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SePGIl1c, HV_BINOP_DIVIDE, 1, m, &cBinop_SePGIl1c_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HXwmhuNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_wpv7uabb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wpv7uabb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RQJt7UMI, m);
}

void Heavy_WSTD_DL3Y::cMsg_gqy46QhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_09oZOhCg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_09oZOhCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0pPRRzfZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CuqLPobR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7qJ6v8qg, m);
}

void Heavy_WSTD_DL3Y::cBinop_eFFc8gXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_8aw4burg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8aw4burg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SePGIl1c, HV_BINOP_DIVIDE, 0, m, &cBinop_SePGIl1c_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SePGIl1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gqy46QhD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Fws3YUld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_s0qBEnNB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_s0qBEnNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_I1toseZB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ziDsUXQv_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Pu7DA4i6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_aPgsslUz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0N1DHGjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_auAbcsNA_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_auAbcsNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KT0IoBAg, HV_BINOP_DIVIDE, 1, m, &cBinop_KT0IoBAg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I1toseZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uF1HMcxP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uF1HMcxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fp26OIgO, m);
}

void Heavy_WSTD_DL3Y::cMsg_5BFOGSHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LYZryBA8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LYZryBA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Fws3YUld_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ziDsUXQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CBRXELsm, m);
}

void Heavy_WSTD_DL3Y::cBinop_aPgsslUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_QLCXBxmi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QLCXBxmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KT0IoBAg, HV_BINOP_DIVIDE, 0, m, &cBinop_KT0IoBAg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KT0IoBAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5BFOGSHU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_zDlEjLs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ztQlEfLy, HV_BINOP_MULTIPLY, 0, m, &cBinop_ztQlEfLy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jtIEjR3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EkEfuGYB_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_EkEfuGYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5iRGN0XF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ztQlEfLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_IO5RGxf9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TLrJwFBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ztQlEfLy, HV_BINOP_MULTIPLY, 1, m, &cBinop_ztQlEfLy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5iRGN0XF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TLrJwFBi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IO5RGxf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_voOAIb6U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_voOAIb6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_5hmXBPry_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Qai4odmV, m);
}

void Heavy_WSTD_DL3Y::cBinop_5hmXBPry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_yUji54x6, m);
}

void Heavy_WSTD_DL3Y::cVar_NKqYXiOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fZtH8F4t, HV_BINOP_MULTIPLY, 0, m, &cBinop_fZtH8F4t_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_n5BvbeWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QvgxAwtf_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_QvgxAwtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yRxdszS1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fZtH8F4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_YKXeMzSZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qSbdZYSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fZtH8F4t, HV_BINOP_MULTIPLY, 1, m, &cBinop_fZtH8F4t_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yRxdszS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qSbdZYSI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YKXeMzSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_0odS3ICB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0odS3ICB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_bfguYeM7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_hVrWLdi8, m);
}

void Heavy_WSTD_DL3Y::cBinop_bfguYeM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_s5yqKLSQ, m);
}

void Heavy_WSTD_DL3Y::sEnv_476lIAOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jPxqZUjS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vmUP6wjI_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ESiHpQVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_WdOJTV2w_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_NlbHFmJh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_btXZCsDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_w9fcW9Jn, HV_BINOP_POW, 0, m, &cBinop_w9fcW9Jn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w9fcW9Jn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mypmlVVL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kWOUmGo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_dpGS7xAC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jPxqZUjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_FehvjtZe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vmUP6wjI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ESiHpQVj, 0, m, &cIf_ESiHpQVj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FehvjtZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ESiHpQVj, 1, m, &cIf_ESiHpQVj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NlbHFmJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_kWOUmGo8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WdOJTV2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_mypmlVVL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_dpGS7xAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w9fcW9Jn, HV_BINOP_POW, 1, m, &cBinop_w9fcW9Jn_sendMessage);
  cMsg_btXZCsDl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_3qjHi6KG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7uAEGUMz, HV_BINOP_MULTIPLY, 0, m, &cBinop_7uAEGUMz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0omD5Mzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1WmOery5_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_1WmOery5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f45SH73U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7uAEGUMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_lwFj152K_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dPNSCheO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7uAEGUMz, HV_BINOP_MULTIPLY, 1, m, &cBinop_7uAEGUMz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f45SH73U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_dPNSCheO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lwFj152K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_HzIrEcEx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HzIrEcEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_yxShIDdq_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_DuQKnmd4, m);
}

void Heavy_WSTD_DL3Y::cBinop_yxShIDdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_BYZb8kxx, m);
}

void Heavy_WSTD_DL3Y::cMsg_mypmlVVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PvKGuvC6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PvKGuvC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_w0TFJN1c, m);
}

void Heavy_WSTD_DL3Y::sEnv_uqw5blMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ykSQuTBT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q4fwTy52_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_8X6y93QT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_3TIN9JwZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_RyWdc3Lu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_riIu4DyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9hjjFUd0, HV_BINOP_POW, 0, m, &cBinop_9hjjFUd0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9hjjFUd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ff81EHS4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_HBSt62oJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_oKe2UN2q_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ykSQuTBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HlGtU0Mg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_q4fwTy52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8X6y93QT, 0, m, &cIf_8X6y93QT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HlGtU0Mg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8X6y93QT, 1, m, &cIf_8X6y93QT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RyWdc3Lu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_HBSt62oJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3TIN9JwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_Ff81EHS4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_oKe2UN2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9hjjFUd0, HV_BINOP_POW, 1, m, &cBinop_9hjjFUd0_sendMessage);
  cMsg_riIu4DyA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_FKI2P7D5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V2uOg5EM, HV_BINOP_MULTIPLY, 0, m, &cBinop_V2uOg5EM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hXWUUfAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0FIkjU3o_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_0FIkjU3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Am71Fxl5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_V2uOg5EM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_sQJCXx2T_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T0hW7Hme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V2uOg5EM, HV_BINOP_MULTIPLY, 1, m, &cBinop_V2uOg5EM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Am71Fxl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_T0hW7Hme_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sQJCXx2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_5sYUSA43_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5sYUSA43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_LfZAVvko_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6wev00gr, m);
}

void Heavy_WSTD_DL3Y::cBinop_LfZAVvko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mFCSHpVE, m);
}

void Heavy_WSTD_DL3Y::cMsg_Ff81EHS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KknBUDwm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KknBUDwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4ZoQ17C6, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_d0ofmHMh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eNlIavjv, 0, m, &cSlice_eNlIavjv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5ThdbTp0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_eNlIavjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7wSfK2Xq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7wSfK2Xq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_RgUH9nqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7wSfK2Xq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_7wSfK2Xq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_apRY9lsd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_kT120afC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DBy82ig1_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_DBy82ig1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_hZ3JIhqh_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_oUjcMmcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oUjcMmcL, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9rflHN7a, 0, m, &cDelay_9rflHN7a_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oUjcMmcL, 0, m, &cDelay_oUjcMmcL_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_nIXEbvKF, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_9rflHN7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9rflHN7a, m);
  cMsg_eSHM4XNK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_wJxTcswM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_UgkpFqoc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_qTB0fyju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oTGVi2yW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_iXucTj5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H2NmoROc_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oUjcMmcL, 2, m, &cDelay_oUjcMmcL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wUJdNNJ6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oTGVi2yW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_iXucTj5e, 0, m, &hTable_iXucTj5e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hZ3JIhqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_qTB0fyju_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eSHM4XNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_iXucTj5e, 0, m, &hTable_iXucTj5e_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wUJdNNJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oUjcMmcL, 0, m, &cDelay_oUjcMmcL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_H2NmoROc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_9rflHN7a, 2, m, &cDelay_9rflHN7a_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UgkpFqoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_nIXEbvKF, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_wVwwKnFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ggRvSnn1, HV_BINOP_SUBTRACT, 0, m, &cBinop_ggRvSnn1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tlXyLbs2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EuulQ2CU_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_EuulQ2CU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_RK0BDrjo_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_sF1ZjPJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xOqAP4hd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_y29EW3Wo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_y29EW3Wo, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_g2Ziypag, 0, m, &cDelay_g2Ziypag_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_QRXUWCl6, 0, m, &sTabread_QRXUWCl6_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_g2Ziypag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_g2Ziypag, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_QRXUWCl6, 0, m, &sTabread_QRXUWCl6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_g2Ziypag, 0, m, &cDelay_g2Ziypag_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_QRXUWCl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Nxj6znGR, HV_BINOP_SUBTRACT, 0, m, &cBinop_Nxj6znGR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_QtrdYkE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rzqF162A, HV_BINOP_MAX, 0, m, &cBinop_rzqF162A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RK0BDrjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QtrdYkE9, HV_BINOP_MULTIPLY, 0, m, &cBinop_QtrdYkE9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ggRvSnn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YHL2E87s_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_QRXUWCl6, 0, m, &sTabread_QRXUWCl6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L2FMsUjp_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_dRttiVsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nxj6znGR, HV_BINOP_SUBTRACT, 1, m, &cBinop_Nxj6znGR_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_g2Ziypag, 2, m, &cDelay_g2Ziypag_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xOqAP4hd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dRttiVsE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YHL2E87s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_y29EW3Wo, 0, m, &cDelay_y29EW3Wo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_g2Ziypag, 0, m, &cDelay_g2Ziypag_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZyfXnGR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_rzqF162A, HV_BINOP_MAX, 1, m, &cBinop_rzqF162A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rzqF162A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ggRvSnn1, HV_BINOP_SUBTRACT, 1, m, &cBinop_ggRvSnn1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_L2FMsUjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_y29EW3Wo, 0, m, &cDelay_y29EW3Wo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lLbQnRMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_y29EW3Wo, 2, m, &cDelay_y29EW3Wo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Nxj6znGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lLbQnRMy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3H7UYuuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sF1ZjPJH, 0, m, &cVar_sF1ZjPJH_sendMessage);
  cMsg_tlXyLbs2_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_wVwwKnFc, 0, m, &cTabhead_wVwwKnFc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bgsGEniG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cb4SKs0c_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_cb4SKs0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_sr7vFrAd_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_kU7rU8ud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kU7rU8ud, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_21DLu2q4, 0, m, &cDelay_21DLu2q4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kU7rU8ud, 0, m, &cDelay_kU7rU8ud_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_qzfDxLi3, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_21DLu2q4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_21DLu2q4, m);
  cMsg_I1LJwlQI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_gdqzLHdr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_J1NLde0V_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_kcyI3Axh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_72aKGZrq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_DNky5wiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KfCvwJDG_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kU7rU8ud, 2, m, &cDelay_kU7rU8ud_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r6efHivY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_72aKGZrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_DNky5wiS, 0, m, &hTable_DNky5wiS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sr7vFrAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_kcyI3Axh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_I1LJwlQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_DNky5wiS, 0, m, &hTable_DNky5wiS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_r6efHivY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kU7rU8ud, 0, m, &cDelay_kU7rU8ud_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KfCvwJDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_21DLu2q4, 2, m, &cDelay_21DLu2q4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_J1NLde0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_qzfDxLi3, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_DoG2FYlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lUOcSdFH, HV_BINOP_SUBTRACT, 0, m, &cBinop_lUOcSdFH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HB5R4eA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YEqGmA7N_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_YEqGmA7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_onzVFW4I_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_HHmQ3HlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x48V6Chp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_WhWxFRkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WhWxFRkN, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tUFPvisn, 0, m, &cDelay_tUFPvisn_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_k5q0SgAa, 0, m, &sTabread_k5q0SgAa_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_tUFPvisn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tUFPvisn, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_k5q0SgAa, 0, m, &sTabread_k5q0SgAa_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tUFPvisn, 0, m, &cDelay_tUFPvisn_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_k5q0SgAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_JKUf9FTK, HV_BINOP_SUBTRACT, 0, m, &cBinop_JKUf9FTK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_IBciKKr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZLDq5jIF, HV_BINOP_MAX, 0, m, &cBinop_ZLDq5jIF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_onzVFW4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IBciKKr8, HV_BINOP_MULTIPLY, 0, m, &cBinop_IBciKKr8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lUOcSdFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RjmJfKnG_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_k5q0SgAa, 0, m, &sTabread_k5q0SgAa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hj8Nnvh0_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_XXlxjih0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JKUf9FTK, HV_BINOP_SUBTRACT, 1, m, &cBinop_JKUf9FTK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tUFPvisn, 2, m, &cDelay_tUFPvisn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_x48V6Chp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XXlxjih0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RjmJfKnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WhWxFRkN, 0, m, &cDelay_WhWxFRkN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tUFPvisn, 0, m, &cDelay_tUFPvisn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iTzjuXRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZLDq5jIF, HV_BINOP_MAX, 1, m, &cBinop_ZLDq5jIF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZLDq5jIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lUOcSdFH, HV_BINOP_SUBTRACT, 1, m, &cBinop_lUOcSdFH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hj8Nnvh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WhWxFRkN, 0, m, &cDelay_WhWxFRkN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8JaFi7pr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WhWxFRkN, 2, m, &cDelay_WhWxFRkN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JKUf9FTK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_8JaFi7pr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yEXtMBMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HHmQ3HlG, 0, m, &cVar_HHmQ3HlG_sendMessage);
  cMsg_HB5R4eA2_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_DoG2FYlI, 0, m, &cTabhead_DoG2FYlI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ACsVug9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Eyq1UhVs, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_YiWc5LFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PsuWTzC8, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_nXpN2kad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I2xYjQg7, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qPWRIbST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WYEUeB51, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_SncsQ6nO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lMl5VLzP, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_FLTe5yzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zpFu6NEx, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_nHqThnA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eOLu3U6x, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Ty6KEUYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4BeIaWg0, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_jpmVgPTl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SEjcGFMb, 0, m, &cSlice_SEjcGFMb_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_SEjcGFMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pabCoTQu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pabCoTQu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_O6aPZ2pp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pabCoTQu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_pabCoTQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SR8UEidz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_I6Lj60O0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Bo0ZQPqI, 0, m, &cSlice_Bo0ZQPqI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vOmXShwU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_Bo0ZQPqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vigKdU3h_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vigKdU3h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_YRiRtKoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vigKdU3h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_vigKdU3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wot8bBgw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_dn4SYSYd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XTKQdY4q, 0, m, &cSlice_XTKQdY4q_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jpmVgPTl_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_XTKQdY4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PVIJLURC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PVIJLURC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_GbWs000S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PVIJLURC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_PVIJLURC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bsANG1IR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7loulb3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_I5In0Ifc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I5In0Ifc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_gngYhGhx_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_rlsowH1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VXPqZKmZ_sendMessage(_c, 0, m);
  cMsg_t4Rw2BzE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_WDxUNHmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0WkcTWQF_sendMessage(_c, 0, m);
  cMsg_9M4DAKg8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gngYhGhx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IFWVhr2v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IFWVhr2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ov52Qdxo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MVkAvKC4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ov52Qdxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_UdSoXbey_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MVkAvKC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YJJNt87n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UdSoXbey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jfabBYOd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YJJNt87n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MzbI1vPl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MzbI1vPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gFB7RS8V_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jfabBYOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_rlsowH1H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gFB7RS8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_WDxUNHmB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_e0TKsanV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_wMjag093_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wMjag093_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_v7MhVJWA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_v7MhVJWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_OrZLqCZP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OrZLqCZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hvWsQSSp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0EAcVptM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hvWsQSSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_JExnh3JC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0EAcVptM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u8jiajlw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JExnh3JC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cXog8QTe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_u8jiajlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_cGtibqyf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cGtibqyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8w0w1ucb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8w0w1ucb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9Rd0t0SY_sendMessage(_c, 0, m);
  cMsg_bMV0pPiG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_cXog8QTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zt4o5EQy_sendMessage(_c, 0, m);
  cMsg_ZFQmhFf1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PITCXPKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_YnI2G3d7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YnI2G3d7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wrW72U8E_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_q7aE4aTs_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_mWY6Gmf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_uRL5KJ0k_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pjykVMiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WdTIKH8m_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_WdTIKH8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WRxrUcD4, HV_BINOP_DIVIDE, 1, m, &cBinop_WRxrUcD4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wrW72U8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TCTXx4xS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TCTXx4xS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7WDvGsGh, m);
}

void Heavy_WSTD_DL3Y::cMsg_MHT3ht31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_u1B06j8w_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u1B06j8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_PITCXPKQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q7aE4aTs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_b1SAE6bB, m);
}

void Heavy_WSTD_DL3Y::cBinop_uRL5KJ0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_vPpkHpRs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vPpkHpRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WRxrUcD4, HV_BINOP_DIVIDE, 0, m, &cBinop_WRxrUcD4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WRxrUcD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MHT3ht31_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5j11jowJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_6exuh4qO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6exuh4qO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RWcIsJxU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_dd3yBe0U_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_1Vn4LyU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_3TqdXSzQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NUJzxvcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4OfHrVyv_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_4OfHrVyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S1J03hNq, HV_BINOP_DIVIDE, 1, m, &cBinop_S1J03hNq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RWcIsJxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dQSwXsDa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dQSwXsDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Tt0X1jcd, m);
}

void Heavy_WSTD_DL3Y::cMsg_2VCzk1ve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LzBCYMmE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LzBCYMmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_5j11jowJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dd3yBe0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4Cnf9xuR, m);
}

void Heavy_WSTD_DL3Y::cBinop_3TqdXSzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_pKfgRoE9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pKfgRoE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S1J03hNq, HV_BINOP_DIVIDE, 0, m, &cBinop_S1J03hNq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_S1J03hNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2VCzk1ve_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_PguyLbSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nRQRumEd, HV_BINOP_MULTIPLY, 0, m, &cBinop_nRQRumEd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_urC2gT0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MEIm8Xww_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_MEIm8Xww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RjieV0hT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nRQRumEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_8NOFpqHj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jBaGggfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nRQRumEd, HV_BINOP_MULTIPLY, 1, m, &cBinop_nRQRumEd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RjieV0hT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jBaGggfn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8NOFpqHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_FDPkGkg7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FDPkGkg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_EqqAj4xu_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BEerFRF6, m);
}

void Heavy_WSTD_DL3Y::cBinop_EqqAj4xu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Qnu5SmC1, m);
}

void Heavy_WSTD_DL3Y::cVar_A3IHHq6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tkYDsgN2, HV_BINOP_MULTIPLY, 0, m, &cBinop_tkYDsgN2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hfrALrRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NkM9HP5T_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_NkM9HP5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qKAxFPUU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tkYDsgN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_gQKg77jo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z9v62M57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tkYDsgN2, HV_BINOP_MULTIPLY, 1, m, &cBinop_tkYDsgN2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qKAxFPUU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Z9v62M57_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gQKg77jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LKfv9oaA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LKfv9oaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_iroYo8Fg_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_K9IfT6kN, m);
}

void Heavy_WSTD_DL3Y::cBinop_iroYo8Fg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_cTQ5yx7M, m);
}

void Heavy_WSTD_DL3Y::sEnv_YxIu2KqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gdxP6uVp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xT0EwxLO_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Fzn4NGZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_dlW9dsRv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_KqVgNhEw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_cErZdk1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fAJPgBWi, HV_BINOP_POW, 0, m, &cBinop_fAJPgBWi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fAJPgBWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_veqjps05_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NTdUHh8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_DUy1eM3m_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gdxP6uVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JGbDk7wJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xT0EwxLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fzn4NGZW, 0, m, &cIf_Fzn4NGZW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JGbDk7wJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fzn4NGZW, 1, m, &cIf_Fzn4NGZW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KqVgNhEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_NTdUHh8e_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dlW9dsRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_veqjps05_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DUy1eM3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fAJPgBWi, HV_BINOP_POW, 1, m, &cBinop_fAJPgBWi_sendMessage);
  cMsg_cErZdk1r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_LE8lQtbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rxmqTBBv, HV_BINOP_MULTIPLY, 0, m, &cBinop_rxmqTBBv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ngNYnvle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vuLSqvt3_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_vuLSqvt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YaJZzjcG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rxmqTBBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_5lXBxDdg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GpLAMPl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rxmqTBBv, HV_BINOP_MULTIPLY, 1, m, &cBinop_rxmqTBBv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YaJZzjcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_GpLAMPl6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5lXBxDdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SXC3sHY3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SXC3sHY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_8gTLPSMl_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BTwM9L8s, m);
}

void Heavy_WSTD_DL3Y::cBinop_8gTLPSMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Qy0xkJaV, m);
}

void Heavy_WSTD_DL3Y::cMsg_veqjps05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pYuMnf2y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pYuMnf2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rKapemfn, m);
}

void Heavy_WSTD_DL3Y::sEnv_roJWg0Yp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L8uRPsSR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J9IyV7sv_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_whRWFk1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_9BCcTFc7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_doTjGqEp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_ynZ6XVtM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8hUpXU63, HV_BINOP_POW, 0, m, &cBinop_8hUpXU63_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8hUpXU63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0niN8ZGC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Pq9jAOdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_UpG7Y4F2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_L8uRPsSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_AnCiNfoV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_J9IyV7sv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_whRWFk1U, 0, m, &cIf_whRWFk1U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AnCiNfoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_whRWFk1U, 1, m, &cIf_whRWFk1U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_doTjGqEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Pq9jAOdA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9BCcTFc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_0niN8ZGC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UpG7Y4F2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8hUpXU63, HV_BINOP_POW, 1, m, &cBinop_8hUpXU63_sendMessage);
  cMsg_ynZ6XVtM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_YiV5Wpnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FLZ1zB5J, HV_BINOP_MULTIPLY, 0, m, &cBinop_FLZ1zB5J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_B6QMNfng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LdMOX6ZA_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_LdMOX6ZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_927PGb0U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FLZ1zB5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_RtjfzdzB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wwEBNTt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FLZ1zB5J, HV_BINOP_MULTIPLY, 1, m, &cBinop_FLZ1zB5J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_927PGb0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wwEBNTt2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RtjfzdzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ztpY0mDQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ztpY0mDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_mNzP4mSs_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_8u9MtGVl, m);
}

void Heavy_WSTD_DL3Y::cBinop_mNzP4mSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_K6VZeEC9, m);
}

void Heavy_WSTD_DL3Y::cMsg_0niN8ZGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_00nPBPyx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_00nPBPyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_M9VCZmam, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_vOmXShwU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EBtSeyTA, 0, m, &cSlice_EBtSeyTA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dn4SYSYd_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_EBtSeyTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WssWkMba_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WssWkMba_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_F2Hkc7NY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WssWkMba_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_WssWkMba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nel4OeW1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_xat8Km4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0UgEODOz_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_0UgEODOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yF7FOScR_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_wxIUCWKu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wxIUCWKu, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VsUokA1Z, 0, m, &cDelay_VsUokA1Z_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wxIUCWKu, 0, m, &cDelay_wxIUCWKu_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_iePjZD9p, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_VsUokA1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VsUokA1Z, m);
  cMsg_XLn2noEz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_rRcS6IW9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_C8WjisSd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_EscdzxXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pLn4N437_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_bqiS5quI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wGHTRijn_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wxIUCWKu, 2, m, &cDelay_wxIUCWKu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DFgSNX47_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pLn4N437_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_bqiS5quI, 0, m, &hTable_bqiS5quI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yF7FOScR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_EscdzxXi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XLn2noEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_bqiS5quI, 0, m, &hTable_bqiS5quI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DFgSNX47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wxIUCWKu, 0, m, &cDelay_wxIUCWKu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wGHTRijn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_VsUokA1Z, 2, m, &cDelay_VsUokA1Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_C8WjisSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_iePjZD9p, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_U3eAW14U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qFxKFAhm, HV_BINOP_SUBTRACT, 0, m, &cBinop_qFxKFAhm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JTv3HLmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZgakcDAG_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ZgakcDAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_L0NT8FIL_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xjFDSqMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hwGrdjk9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_YQp27iHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YQp27iHF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jVPw6xJw, 0, m, &cDelay_jVPw6xJw_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pnTWeUHV, 0, m, &sTabread_pnTWeUHV_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_jVPw6xJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jVPw6xJw, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pnTWeUHV, 0, m, &sTabread_pnTWeUHV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jVPw6xJw, 0, m, &cDelay_jVPw6xJw_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_pnTWeUHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_7lc8xFvJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_7lc8xFvJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_475eLQvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MLb3dSSC, HV_BINOP_MAX, 0, m, &cBinop_MLb3dSSC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_L0NT8FIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_475eLQvT, HV_BINOP_MULTIPLY, 0, m, &cBinop_475eLQvT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qFxKFAhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m3rTEAC2_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_pnTWeUHV, 0, m, &sTabread_pnTWeUHV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZvJdaes9_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_dDpAynMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7lc8xFvJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_7lc8xFvJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jVPw6xJw, 2, m, &cDelay_jVPw6xJw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hwGrdjk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dDpAynMu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_m3rTEAC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YQp27iHF, 0, m, &cDelay_YQp27iHF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jVPw6xJw, 0, m, &cDelay_jVPw6xJw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mPV0jrIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_MLb3dSSC, HV_BINOP_MAX, 1, m, &cBinop_MLb3dSSC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MLb3dSSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qFxKFAhm, HV_BINOP_SUBTRACT, 1, m, &cBinop_qFxKFAhm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZvJdaes9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YQp27iHF, 0, m, &cDelay_YQp27iHF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rdMt5Lkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YQp27iHF, 2, m, &cDelay_YQp27iHF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7lc8xFvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rdMt5Lkx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EJvr0Aa7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xjFDSqMK, 0, m, &cVar_xjFDSqMK_sendMessage);
  cMsg_JTv3HLmx_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_U3eAW14U, 0, m, &cTabhead_U3eAW14U_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_h3YFcZE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TKscVoQ5_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_TKscVoQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_TqjwthEY_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_jwlDV6O9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jwlDV6O9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_L3snhHOf, 0, m, &cDelay_L3snhHOf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jwlDV6O9, 0, m, &cDelay_jwlDV6O9_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Rw9AfzaL, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_L3snhHOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_L3snhHOf, m);
  cMsg_PMP6nr14_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_TtxKvf1E_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_lEpECXb1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_0leEHXBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Iq0XmHwT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_iIguDIux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BioymhIp_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jwlDV6O9, 2, m, &cDelay_jwlDV6O9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_upnxKniW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Iq0XmHwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_iIguDIux, 0, m, &hTable_iIguDIux_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TqjwthEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_0leEHXBL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PMP6nr14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_iIguDIux, 0, m, &hTable_iIguDIux_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_upnxKniW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jwlDV6O9, 0, m, &cDelay_jwlDV6O9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BioymhIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_L3snhHOf, 2, m, &cDelay_L3snhHOf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lEpECXb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_Rw9AfzaL, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_U24O6zxy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yQBYDbZX, HV_BINOP_SUBTRACT, 0, m, &cBinop_yQBYDbZX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Hmn8gnSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pmD3rosd_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_pmD3rosd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_QPCiQu1r_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_oH3J3pKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ibMviyQZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_oPnM2ddA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oPnM2ddA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rgZ0I8Ko, 0, m, &cDelay_rgZ0I8Ko_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_VnMc8tu7, 0, m, &sTabread_VnMc8tu7_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_rgZ0I8Ko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rgZ0I8Ko, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_VnMc8tu7, 0, m, &sTabread_VnMc8tu7_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rgZ0I8Ko, 0, m, &cDelay_rgZ0I8Ko_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_VnMc8tu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Ee1xMoiV, HV_BINOP_SUBTRACT, 0, m, &cBinop_Ee1xMoiV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_dD5JDzOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ApR0Z1jL, HV_BINOP_MAX, 0, m, &cBinop_ApR0Z1jL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QPCiQu1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dD5JDzOZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_dD5JDzOZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yQBYDbZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ou8E5LJ3_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_VnMc8tu7, 0, m, &sTabread_VnMc8tu7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nUs9p8GH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_47cUXVpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ee1xMoiV, HV_BINOP_SUBTRACT, 1, m, &cBinop_Ee1xMoiV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rgZ0I8Ko, 2, m, &cDelay_rgZ0I8Ko_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ibMviyQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_47cUXVpe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ou8E5LJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oPnM2ddA, 0, m, &cDelay_oPnM2ddA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rgZ0I8Ko, 0, m, &cDelay_rgZ0I8Ko_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EkZZq46M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ApR0Z1jL, HV_BINOP_MAX, 1, m, &cBinop_ApR0Z1jL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ApR0Z1jL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yQBYDbZX, HV_BINOP_SUBTRACT, 1, m, &cBinop_yQBYDbZX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nUs9p8GH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oPnM2ddA, 0, m, &cDelay_oPnM2ddA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gX1HtxdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oPnM2ddA, 2, m, &cDelay_oPnM2ddA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ee1xMoiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_gX1HtxdF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SrHRe9xz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oH3J3pKX, 0, m, &cVar_oH3J3pKX_sendMessage);
  cMsg_Hmn8gnSq_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_U24O6zxy, 0, m, &cTabhead_U24O6zxy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VXPqZKmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4rIt9OwS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_0WkcTWQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kuQyRfmZ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_9M4DAKg8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VXQ6647x, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_t4Rw2BzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FuVhpRJE, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ZFQmhFf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_svDIXkYh, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_9Rd0t0SY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NYYMYq9u, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Zt4o5EQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tZlMqJEQ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_bMV0pPiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EblTejTF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_e8SGvQom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Mdozp5cc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xsYVvWrz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_AVjV6RBJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Mdozp5cc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e8SGvQom, 1, m, &cVar_e8SGvQom_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_1fOtK75r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_kVGDrYAM, 0, m, &cVar_kVGDrYAM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_K8bdEZgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_kVGDrYAM, 0, m, &cVar_kVGDrYAM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_8mCIUVCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K8bdEZgw, 0, m, &cIf_K8bdEZgw_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_166D6dMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1fOtK75r, 0, m, &cIf_1fOtK75r_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_yxTCAXmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0PVem4zJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TfgvhOe5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IVhlNFqc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0PVem4zJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yxTCAXmb, 1, m, &cVar_yxTCAXmb_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_MGRyxWuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_4OZYgtIN, 0, m, &cVar_4OZYgtIN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_Wo0CX1kM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_4OZYgtIN, 0, m, &cVar_4OZYgtIN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_f0XtACiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wo0CX1kM, 0, m, &cIf_Wo0CX1kM_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_fGQp8JdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MGRyxWuA, 0, m, &cIf_MGRyxWuA_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_DPKOMGkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EoAA9QgX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_scjDgKRr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OoprEtVN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EoAA9QgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DPKOMGkw, 1, m, &cVar_DPKOMGkw_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_GpvMrZ4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Gbo0ywP1, 0, m, &cVar_Gbo0ywP1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_RJm0WKwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Gbo0ywP1, 0, m, &cVar_Gbo0ywP1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_sleystaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RJm0WKwk, 0, m, &cIf_RJm0WKwk_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_wQKhwR8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GpvMrZ4N, 0, m, &cIf_GpvMrZ4N_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_MEC49OZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nR0jqm4e, HV_BINOP_DIVIDE, 0, m, &cBinop_nR0jqm4e_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_pfNpKvzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bmHtl2TY, HV_BINOP_MULTIPLY, 1, m, &cBinop_bmHtl2TY_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_s1ncPnoc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_c55JulEv, 0, m, &cSlice_c55JulEv_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GAYhMoIf, 0, m, &cSlice_GAYhMoIf_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h0Li9O61_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1TKP5aYv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_c55JulEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_xqhtGuhA, 0, m, &cVar_xqhtGuhA_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_xqhtGuhA, 0, m, &cVar_xqhtGuhA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_GAYhMoIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_yIavPIZz, HV_BINOP_NEQ, 1, m, &cBinop_yIavPIZz_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_xqhtGuhA, 1, m, &cVar_xqhtGuhA_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_yIavPIZz, HV_BINOP_NEQ, 1, m, &cBinop_yIavPIZz_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_xqhtGuhA, 1, m, &cVar_xqhtGuhA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_xqhtGuhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_Hu3KDIR3_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_zcv66dDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2E5yO7uw_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BfPPaP79_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_BfPPaP79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xqhtGuhA, 0, m, &cVar_xqhtGuhA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2E5yO7uw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yIavPIZz, HV_BINOP_NEQ, 1, m, &cBinop_yIavPIZz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yIavPIZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zcv66dDl, 1, m, &cIf_zcv66dDl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_h0Li9O61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yIavPIZz, HV_BINOP_NEQ, 0, m, &cBinop_yIavPIZz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1TKP5aYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zcv66dDl, 0, m, &cIf_zcv66dDl_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_UkUN1eN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AGHqdj87_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pzB4cHP1_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_aiQ0J4D1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U8JphR1L_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ghbvgHDs_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5v7QPgjq_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i06C1pic_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5qXzyeGk_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VKXCqZLF_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rOYoL0rB_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_27XyP0qs_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1vJIWGYh_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XRIyZxvB_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nKTGbCac_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ap2UHB3T_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uxZ1Z1dN_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_U8JphR1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BEkS9TFf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ghbvgHDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A3n2ZD6a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_5v7QPgjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yWASQPjU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_i06C1pic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9tSFqtQR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_5qXzyeGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XQK9TK97_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_VKXCqZLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cGLdWpDZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_rOYoL0rB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wLQgAxbr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_27XyP0qs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OcPKHx0L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_1vJIWGYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wL23org5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_XRIyZxvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lu5ScSNe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_nKTGbCac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aKnuh25H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ap2UHB3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YQK7rWWq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_uxZ1Z1dN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hTGTG6Br_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nR0jqm4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bmHtl2TY, HV_BINOP_MULTIPLY, 0, m, &cBinop_bmHtl2TY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bmHtl2TY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_s1ncPnoc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_pzB4cHP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MEC49OZJ, 0, m, &cVar_MEC49OZJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pfNpKvzF, 0, m, &cVar_pfNpKvzF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AGHqdj87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nR0jqm4e, HV_BINOP_DIVIDE, 1, m, &cBinop_nR0jqm4e_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0p8NJOmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MEC49OZJ, 0, m, &cVar_MEC49OZJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QyNDjNan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pfNpKvzF, 0, m, &cVar_pfNpKvzF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BEkS9TFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QyNDjNan_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0p8NJOmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_A3n2ZD6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QyNDjNan_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0p8NJOmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yWASQPjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QyNDjNan_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0p8NJOmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9tSFqtQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QyNDjNan_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0p8NJOmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XQK9TK97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QyNDjNan_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0p8NJOmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cGLdWpDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QyNDjNan_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0p8NJOmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wLQgAxbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QyNDjNan_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0p8NJOmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OcPKHx0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QyNDjNan_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0p8NJOmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wL23org5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QyNDjNan_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0p8NJOmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lu5ScSNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QyNDjNan_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0p8NJOmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aKnuh25H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QyNDjNan_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0p8NJOmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YQK7rWWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QyNDjNan_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0p8NJOmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hTGTG6Br_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QyNDjNan_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0p8NJOmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_E7gpAWu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aiFnLhp9, HV_BINOP_DIVIDE, 0, m, &cBinop_aiFnLhp9_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_588vX11u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tCV8m4CJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_tCV8m4CJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_hl85O140_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_I67l3l8l, 0, m, &cSlice_I67l3l8l_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XUMAN3T8, 0, m, &cSlice_XUMAN3T8_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0iJ9G3Mw_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8cALQkCO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_I67l3l8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_gNI5rN2P, 0, m, &cVar_gNI5rN2P_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_gNI5rN2P, 0, m, &cVar_gNI5rN2P_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_XUMAN3T8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2jUBamDg, HV_BINOP_NEQ, 1, m, &cBinop_2jUBamDg_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_gNI5rN2P, 1, m, &cVar_gNI5rN2P_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2jUBamDg, HV_BINOP_NEQ, 1, m, &cBinop_2jUBamDg_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_gNI5rN2P, 1, m, &cVar_gNI5rN2P_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_gNI5rN2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_gYmqHZCt_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_B8DIKr7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q4PEa4xN_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xlPmRRp9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_xlPmRRp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gNI5rN2P, 0, m, &cVar_gNI5rN2P_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_q4PEa4xN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2jUBamDg, HV_BINOP_NEQ, 1, m, &cBinop_2jUBamDg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2jUBamDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B8DIKr7f, 1, m, &cIf_B8DIKr7f_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0iJ9G3Mw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2jUBamDg, HV_BINOP_NEQ, 0, m, &cBinop_2jUBamDg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8cALQkCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B8DIKr7f, 0, m, &cIf_B8DIKr7f_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_JH8TRNMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qwlm4NDN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zp4XfN1i_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_w7X4oI05_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LZxqPSfj_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ko8ChRyO_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hyw3Getc_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pDr94WOl_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fNzJkyn5_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j7lW3Z9Y_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GvBaUyB3_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L33zCViI_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FfgxzH8F_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tsvbHUf3_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KdFEvk7A_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q10vZyV1_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xgoacyFK_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_LZxqPSfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5uJjwNQ8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Ko8ChRyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kkShsrEb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_hyw3Getc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dOGkjwnx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_pDr94WOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X5F88kL9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_fNzJkyn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6uMaU1r6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_j7lW3Z9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SU9JJNSI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_GvBaUyB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wPm2GoW7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_L33zCViI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y19FPZnz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_FfgxzH8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T81mgwy9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_tsvbHUf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n9fj5H7U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_KdFEvk7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kzPq8ZEa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_q10vZyV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iC3v70SP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_xgoacyFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sUibqP6s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_aiFnLhp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tCV8m4CJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_tCV8m4CJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tCV8m4CJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hl85O140_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_Qwlm4NDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aiFnLhp9, HV_BINOP_DIVIDE, 1, m, &cBinop_aiFnLhp9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zp4XfN1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E7gpAWu0, 0, m, &cVar_E7gpAWu0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_588vX11u, 0, m, &cVar_588vX11u_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Tedy7suO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E7gpAWu0, 0, m, &cVar_E7gpAWu0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cuaLhRjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_588vX11u, 0, m, &cVar_588vX11u_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5uJjwNQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cuaLhRjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tedy7suO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kkShsrEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cuaLhRjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tedy7suO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dOGkjwnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cuaLhRjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tedy7suO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_X5F88kL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cuaLhRjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tedy7suO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6uMaU1r6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cuaLhRjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tedy7suO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SU9JJNSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cuaLhRjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tedy7suO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wPm2GoW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cuaLhRjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tedy7suO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Y19FPZnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cuaLhRjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tedy7suO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_T81mgwy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cuaLhRjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tedy7suO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_n9fj5H7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cuaLhRjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tedy7suO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kzPq8ZEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cuaLhRjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tedy7suO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iC3v70SP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cuaLhRjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tedy7suO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sUibqP6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cuaLhRjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tedy7suO_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ovKwLRbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sqqEXtxe, HV_BINOP_DIVIDE, 0, m, &cBinop_sqqEXtxe_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_EXHsuyue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jexJFChN, HV_BINOP_MULTIPLY, 1, m, &cBinop_jexJFChN_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ixgvrYaW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xf4hrMDq, 0, m, &cSlice_xf4hrMDq_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hU9uElxt, 0, m, &cSlice_hU9uElxt_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cxaFHDSA_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LgtiSp7G_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_xf4hrMDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_d9rU2L4S, 0, m, &cVar_d9rU2L4S_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_d9rU2L4S, 0, m, &cVar_d9rU2L4S_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_hU9uElxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_YOBmjGru, HV_BINOP_NEQ, 1, m, &cBinop_YOBmjGru_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_d9rU2L4S, 1, m, &cVar_d9rU2L4S_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_YOBmjGru, HV_BINOP_NEQ, 1, m, &cBinop_YOBmjGru_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_d9rU2L4S, 1, m, &cVar_d9rU2L4S_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_d9rU2L4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_6BTKaKxC_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ze1FLYWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5Dq1xAKF_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kpcDxOoe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_kpcDxOoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d9rU2L4S, 0, m, &cVar_d9rU2L4S_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5Dq1xAKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YOBmjGru, HV_BINOP_NEQ, 1, m, &cBinop_YOBmjGru_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YOBmjGru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ze1FLYWU, 1, m, &cIf_ze1FLYWU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cxaFHDSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YOBmjGru, HV_BINOP_NEQ, 0, m, &cBinop_YOBmjGru_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LgtiSp7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ze1FLYWU, 0, m, &cIf_ze1FLYWU_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_DY6IRRJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hUk7D4eG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jmKoiPzd_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_sdw6P4aM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_396X8lGN_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hBrn9JIQ_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YlVa8YbW_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uH5wo4lY_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4xJWfEW0_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fZIF1h3I_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kyVzuQuT_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eHNX4BqW_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vXAZRyR2_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ydLzLq0E_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wvOTSdK0_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AXp7C7Am_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x3O3RFbJ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_396X8lGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jENvUAuU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_hBrn9JIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RKMDObj7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_YlVa8YbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_igT7zTDH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_uH5wo4lY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xiHkQzGA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_4xJWfEW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JuTsGT9L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_fZIF1h3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YDVHpyi8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_kyVzuQuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kp1ujuZZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_eHNX4BqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vXxzT3tR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_vXAZRyR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hSdcN9jZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ydLzLq0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k8QnFqro_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_wvOTSdK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RNk10Hbf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_AXp7C7Am_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qqsIRrCB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_x3O3RFbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SAun03Hp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_sqqEXtxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jexJFChN, HV_BINOP_MULTIPLY, 0, m, &cBinop_jexJFChN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jexJFChN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ixgvrYaW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_jmKoiPzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ovKwLRbz, 0, m, &cVar_ovKwLRbz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EXHsuyue, 0, m, &cVar_EXHsuyue_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hUk7D4eG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sqqEXtxe, HV_BINOP_DIVIDE, 1, m, &cBinop_sqqEXtxe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lrBXy43F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EXHsuyue, 0, m, &cVar_EXHsuyue_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qXnTbVar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ovKwLRbz, 0, m, &cVar_ovKwLRbz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jENvUAuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrBXy43F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qXnTbVar_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RKMDObj7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrBXy43F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qXnTbVar_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_igT7zTDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrBXy43F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qXnTbVar_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xiHkQzGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrBXy43F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qXnTbVar_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JuTsGT9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrBXy43F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qXnTbVar_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YDVHpyi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrBXy43F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qXnTbVar_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Kp1ujuZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrBXy43F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qXnTbVar_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vXxzT3tR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrBXy43F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qXnTbVar_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hSdcN9jZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrBXy43F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qXnTbVar_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_k8QnFqro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrBXy43F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qXnTbVar_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RNk10Hbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrBXy43F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qXnTbVar_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qqsIRrCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrBXy43F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qXnTbVar_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SAun03Hp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrBXy43F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qXnTbVar_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rIIO5LAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4T49Dp0A_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_UfjqCsaI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tP2yXRiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4T49Dp0A_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_UfjqCsaI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_iS7JA9XO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4T49Dp0A_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_UfjqCsaI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_vtPWd1CV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4T49Dp0A_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_UfjqCsaI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ADni1T7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4T49Dp0A_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_UfjqCsaI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Nl2ZEVQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_skBdHZNw, 0, m, &cVar_skBdHZNw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ISqNBG1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_9K6EzhZk, 0, m, &cVar_9K6EzhZk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4tXxnlGC, 0, m, &cVar_4tXxnlGC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8haFuEXX, 0, m, &cVar_8haFuEXX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RZ6KRXPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CA1fPuoq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_sAaxYbgQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CA1fPuoq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_Zv0blEln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e8tgKWrc, 0, m, &cVar_e8tgKWrc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UuKjed0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NkvbTTvN, 0, m, &cVar_NkvbTTvN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2xiZoH97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6I8XEJ1O, 0, m, &cVar_6I8XEJ1O_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_c4RwmMn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CA1fPuoq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3r0OO8b5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_CA1fPuoq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_dfiRwytA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_v27LEz6c_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_IMeMu1sR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_v27LEz6c_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_1a8uGSQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oECDjVgs, 0, m, &cVar_oECDjVgs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9VdHLoTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eLvMGduN, 0, m, &cVar_eLvMGduN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZR65oUg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3M6cWgcG, 0, m, &cVar_3M6cWgcG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dRUNec6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_v27LEz6c_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_mZruvoqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_v27LEz6c_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_CJ2S3kMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_I6Lj60O0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6uf6guqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_I6Lj60O0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_Ttl59eFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KApAWxsj, 0, m, &cVar_KApAWxsj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V0VBYqwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vSjk6RCF, 0, m, &cVar_vSjk6RCF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_f1aDs70L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C7zNzSu1, 0, m, &cVar_C7zNzSu1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9xAWuU1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_I6Lj60O0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zv4UsHy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_I6Lj60O0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_Hu3KDIR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_166D6dMy, 0, m, &cVar_166D6dMy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AVjV6RBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dXNGpsnu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dl3Ot26v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xsYVvWrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UpDtWR0i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mUgw13XV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mUgw13XV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8mCIUVCV, 0, m, &cVar_8mCIUVCV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UpDtWR0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K8bdEZgw, 1, m, &cIf_K8bdEZgw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dl3Ot26v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_166D6dMy, 0, m, &cVar_166D6dMy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dXNGpsnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1fOtK75r, 1, m, &cIf_1fOtK75r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gYmqHZCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fGQp8JdV, 0, m, &cVar_fGQp8JdV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IVhlNFqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UjaXNhfY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cBqP8Pet_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TfgvhOe5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lDJL9hea_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_maCNIRfP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_maCNIRfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f0XtACiw, 0, m, &cVar_f0XtACiw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lDJL9hea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wo0CX1kM, 1, m, &cIf_Wo0CX1kM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UjaXNhfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MGRyxWuA, 1, m, &cIf_MGRyxWuA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cBqP8Pet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fGQp8JdV, 0, m, &cVar_fGQp8JdV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6BTKaKxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wQKhwR8l, 0, m, &cVar_wQKhwR8l_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OoprEtVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Gd4wQJ1A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vNHUoodp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_scjDgKRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QL2qR2XD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O1eLBt6r_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_O1eLBt6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sleystaz, 0, m, &cVar_sleystaz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QL2qR2XD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RJm0WKwk, 1, m, &cIf_RJm0WKwk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vNHUoodp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wQKhwR8l, 0, m, &cVar_wQKhwR8l_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Gd4wQJ1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GpvMrZ4N, 1, m, &cIf_GpvMrZ4N_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ary8fWsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9K6EzhZk, 0, m, &cVar_9K6EzhZk_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_USKv6yV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4tXxnlGC, 0, m, &cVar_4tXxnlGC_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_yVuAzmi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8haFuEXX, 0, m, &cVar_8haFuEXX_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_cY2o4y3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eYQcZ6MQ, 0, m, &cVar_eYQcZ6MQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_g1HkUfYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qcAyJaRp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ScXZYEgi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ZgUQ0Wq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f746IhJg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vfKku4Vl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_udHuPjOQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_jnwO4YA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yNxGvrlx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8CVs7rMS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_map1CqTN_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wzNu8L86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QbMlYcRa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N0nkBIdr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jhccuJ7X_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_4qv0PuiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XYdY8O9r_sendMessage(_c, 0, m);
  cMsg_BC9D6mns_sendMessage(_c, 0, m);
  cMsg_SJd5bmDr_sendMessage(_c, 0, m);
  cMsg_OZo8znFP_sendMessage(_c, 0, m);
  cMsg_oImdtuwG_sendMessage(_c, 0, m);
  cMsg_9yCewEa2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wKppoZJP, 0, m, &cVar_wKppoZJP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eYQcZ6MQ, 0, m, &cVar_eYQcZ6MQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cfBvbOuF, 0, m, &cVar_cfBvbOuF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zcs1Z90u, 0, m, &cVar_zcs1Z90u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4JIAjRFc, 0, m, &cVar_4JIAjRFc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cK4Xxqaa, 0, m, &cVar_cK4Xxqaa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eL06RVxC, 0, m, &cVar_eL06RVxC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BALlMcNL, 0, m, &cVar_BALlMcNL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Rb4E6LVJ, 0, m, &cVar_Rb4E6LVJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qxFLug7l, 0, m, &cVar_qxFLug7l_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nBdXZ5fK, 0, m, &cVar_nBdXZ5fK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rGCgnthK, 0, m, &cVar_rGCgnthK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CrrXzfju, 0, m, &cVar_CrrXzfju_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_svKJDjUY, 0, m, &cVar_svKJDjUY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7ebw265P, 0, m, &cVar_7ebw265P_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Bd10jSk9, 0, m, &cVar_Bd10jSk9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QNEQxQkp, 0, m, &cVar_QNEQxQkp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_R1tZj1hy, 0, m, &cVar_R1tZj1hy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tz5Wrkie, 0, m, &cVar_tz5Wrkie_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jnR0RceH, 0, m, &cVar_jnR0RceH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lAoPmes5, 0, m, &cVar_lAoPmes5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QxXlFph3, 0, m, &cVar_QxXlFph3_sendMessage);
  cMsg_3Fe2cEz3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WYUqzyM6, 0, m, &cVar_WYUqzyM6_sendMessage);
  cMsg_CYjfstug_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WrJu9tF8, 0, m, &cVar_WrJu9tF8_sendMessage);
  cMsg_0omD5Mzr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3qjHi6KG, 0, m, &cVar_3qjHi6KG_sendMessage);
  cMsg_hXWUUfAi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_FKI2P7D5, 0, m, &cVar_FKI2P7D5_sendMessage);
  cMsg_ngNYnvle_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_LE8lQtbZ, 0, m, &cVar_LE8lQtbZ_sendMessage);
  cMsg_B6QMNfng_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YiV5Wpnx, 0, m, &cVar_YiV5Wpnx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RaK3I23A, 0, m, &cVar_RaK3I23A_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_80CZ8oDr, 0, m, &cVar_80CZ8oDr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_O6lgFkxU, 0, m, &cVar_O6lgFkxU_sendMessage);
  cMsg_jyBfMCeo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3quvafgk, 0, m, &cVar_3quvafgk_sendMessage);
  cMsg_Q0rs2hZZ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cRliIBoH, 0, m, &cVar_cRliIBoH_sendMessage);
  cMsg_Ww0hCeo4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_4NqMeyxQ, 0, m, &cVar_4NqMeyxQ_sendMessage);
  cMsg_hZRaV4Ja_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_s5ghIzpM, 0, m, &cVar_s5ghIzpM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xfAub66P, 0, m, &cVar_xfAub66P_sendMessage);
  cMsg_60IY5otT_sendMessage(_c, 0, m);
  cMsg_k2cHubtk_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qNJC89rL, 0, m, &cVar_qNJC89rL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Xi511yDy, 0, m, &cVar_Xi511yDy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lK6nCmOc, 0, m, &cVar_lK6nCmOc_sendMessage);
  cMsg_8bMqbcav_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3kSN98pg, 0, m, &cVar_3kSN98pg_sendMessage);
  cMsg_0N1DHGjl_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Pu7DA4i6, 0, m, &cVar_Pu7DA4i6_sendMessage);
  cMsg_jtIEjR3x_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zDlEjLs6, 0, m, &cVar_zDlEjLs6_sendMessage);
  cMsg_n5BvbeWn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_NKqYXiOe, 0, m, &cVar_NKqYXiOe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RgUH9nqQ, 0, m, &cVar_RgUH9nqQ_sendMessage);
  cMsg_kT120afC_sendMessage(_c, 0, m);
  cMsg_bgsGEniG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_O6aPZ2pp, 0, m, &cVar_O6aPZ2pp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YRiRtKoH, 0, m, &cVar_YRiRtKoH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GbWs000S, 0, m, &cVar_GbWs000S_sendMessage);
  cMsg_pjykVMiN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_mWY6Gmf9, 0, m, &cVar_mWY6Gmf9_sendMessage);
  cMsg_NUJzxvcX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1Vn4LyU6, 0, m, &cVar_1Vn4LyU6_sendMessage);
  cMsg_urC2gT0f_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PguyLbSn, 0, m, &cVar_PguyLbSn_sendMessage);
  cMsg_hfrALrRx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_A3IHHq6Q, 0, m, &cVar_A3IHHq6Q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_F2Hkc7NY, 0, m, &cVar_F2Hkc7NY_sendMessage);
  cMsg_xat8Km4k_sendMessage(_c, 0, m);
  cMsg_h3YFcZE9_sendMessage(_c, 0, m);
  cMsg_ISqNBG1s_sendMessage(_c, 0, m);
  cMsg_Nl2ZEVQn_sendMessage(_c, 0, m);
  cMsg_yV3xrgzO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_x1xIkQ9p, 0, m, &cVar_x1xIkQ9p_sendMessage);
  cMsg_jRQbJyzI_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_kKrKBgH0, 0, m, &cTabhead_kKrKBgH0_sendMessage);
  cMsg_TfFjMlrS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sRmzWkhF, 0, m, &cVar_sRmzWkhF_sendMessage);
  cMsg_h6I1OXCQ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_RnQiAKn2, 0, m, &cTabhead_RnQiAKn2_sendMessage);
  cMsg_ZyfXnGR3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sF1ZjPJH, 0, m, &cVar_sF1ZjPJH_sendMessage);
  cMsg_tlXyLbs2_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_wVwwKnFc, 0, m, &cTabhead_wVwwKnFc_sendMessage);
  cMsg_iTzjuXRB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_HHmQ3HlG, 0, m, &cVar_HHmQ3HlG_sendMessage);
  cMsg_HB5R4eA2_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_DoG2FYlI, 0, m, &cTabhead_DoG2FYlI_sendMessage);
  cMsg_mPV0jrIM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xjFDSqMK, 0, m, &cVar_xjFDSqMK_sendMessage);
  cMsg_JTv3HLmx_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_U3eAW14U, 0, m, &cTabhead_U3eAW14U_sendMessage);
  cMsg_EkZZq46M_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_oH3J3pKX, 0, m, &cVar_oH3J3pKX_sendMessage);
  cMsg_Hmn8gnSq_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_U24O6zxy, 0, m, &cTabhead_U24O6zxy_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_7PR2ebK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gvbEwwaR, HV_BINOP_MULTIPLY, 0, m, &cBinop_gvbEwwaR_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5eiemZrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NTd1kT7A_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_aUl2QcZF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_QpEfikp4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_4VKsnRYT_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_SqzbEjA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gMTo3rOU_sendMessage);
  cMsg_tXDRoGEM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_hscY8OiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vU7zvt1z, HV_BINOP_MULTIPLY, 0, m, &cBinop_vU7zvt1z_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Fl5w11gv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_TCp5lQ4c_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_tZIfJMs2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kje2wcjo, HV_BINOP_MULTIPLY, 1, m, &cBinop_Kje2wcjo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mSkT8X3N_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KN7aSwnA_sendMessage);
  cMsg_zA1kwHvh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_2Zrd1yCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fcmBqiwr, HV_BINOP_MULTIPLY, 0, m, &cBinop_fcmBqiwr_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_nTN11LpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ohdKX5Gf_sendMessage(_c, 0, m);
  cMsg_s3tkvDQH_sendMessage(_c, 0, m);
  cMsg_KQcFtpeN_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_NakwQqQ1_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_fsPHLeeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jv5VyWOm_sendMessage);
  cMsg_tRi8jbEG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_gi8SkX4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4JIAjRFc, 0, m, &cVar_4JIAjRFc_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_uOYIvocj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H9ijAUxJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eV7iGUlh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_HLYu0QzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mcs0DOOL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ozCIBWnZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7bLlDhlw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_VFLY7H80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v7cnT5w9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7g0IHiED_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KZGd477j_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_iAC0IYzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N57B1y0O_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SqDyEq0d_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oN8lEQNO_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_UT2rYG8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U9ywQ3MA, HV_BINOP_MULTIPLY, 0, m, &cBinop_U9ywQ3MA_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_xNOpJCkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_E5FAc3Gl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3ekTlkIB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_nkQWjBYF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_m81xvBGf_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_EzkjrWnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jT7R54Nl_sendMessage);
  cMsg_PHQHMSQi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_VrMcHY7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dkwrDPPP, HV_BINOP_MULTIPLY, 0, m, &cBinop_dkwrDPPP_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_qh5w0bMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_K8UefCAo_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5Z7pifbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3nG7CFva, HV_BINOP_MULTIPLY, 1, m, &cBinop_3nG7CFva_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_fNecWXsl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rhi9nxns_sendMessage);
  cMsg_d4fINlKk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_5bxpUvHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WF0ZfEtJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_WF0ZfEtJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_M2dDOz8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qLYsL4xM_sendMessage(_c, 0, m);
  cMsg_xV5nu3DL_sendMessage(_c, 0, m);
  cMsg_U0OBe6PK_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_TaZ3QR4q_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_9KPw4WJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_cyX5Tifd_sendMessage);
  cMsg_Dk0wajA7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_v7GHc9hT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_skBdHZNw, 0, m, &cVar_skBdHZNw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_HPBqw4vP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Zv0blEln_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_sACxT3Oy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_UuKjed0l_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_x8hMW9yF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_2xiZoH97_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_KT2Uv5JT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_1a8uGSQA_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_0caZlisb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_9VdHLoTW_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_z8yEl8iL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Ttl59eFu_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_nylIk1K4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_V0VBYqwh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_7wVrtn2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_f1aDs70L_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_tZ30Aa7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ZR65oUg4_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Vn9IU9L4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mliwy4jo, HV_BINOP_MULTIPLY, 1, m, &cBinop_Mliwy4jo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ypy8S1Mv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5wQqil91, HV_BINOP_MULTIPLY, 1, m, &cBinop_5wQqil91_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nX71wbx7_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_pD2OMkmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FPRlUv2i, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_9fqlzBXs, m);
}

void Heavy_WSTD_DL3Y::cReceive_MvrF1fwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_glJbYqxi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_SZoeBqn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_567wkRoA_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_RqtNdhU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QtrdYkE9, HV_BINOP_MULTIPLY, 1, m, &cBinop_QtrdYkE9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3H7UYuuV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IBciKKr8, HV_BINOP_MULTIPLY, 1, m, &cBinop_IBciKKr8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yEXtMBMV_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_apRY9lsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_epnkhGKF, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BrG2ex7S, m);
}

void Heavy_WSTD_DL3Y::cReceive_TBPSKCeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_2wo0kVZ0_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_K5PK4Gby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_K8D5EhQU_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_bsANG1IR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_475eLQvT, HV_BINOP_MULTIPLY, 1, m, &cBinop_475eLQvT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EJvr0Aa7_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dD5JDzOZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_dD5JDzOZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SrHRe9xz_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_nel4OeW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_a4BL4mle, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lXaurTNU, m);
}

void Heavy_WSTD_DL3Y::cReceive_SR8UEidz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_7loulb3B_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wot8bBgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_e0TKsanV_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_vZt7J1l6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8mCIUVCV, 0, m, &cVar_8mCIUVCV_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_aRa7y4Ps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e8SGvQom, 0, m, &cVar_e8SGvQom_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_w49CFvVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yxTCAXmb, 0, m, &cVar_yxTCAXmb_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ggeOqn5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f0XtACiw, 0, m, &cVar_f0XtACiw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_AA5BoCUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sleystaz, 0, m, &cVar_sleystaz_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_koAGPBk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DPKOMGkw, 0, m, &cVar_DPKOMGkw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_oT9R2PrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UkUN1eN7, 0, m, &cVar_UkUN1eN7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JH8TRNMP, 0, m, &cVar_JH8TRNMP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DY6IRRJm, 0, m, &cVar_DY6IRRJm_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_YDs66Ksb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_w7X4oI05_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_bZDZBPNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aiQ0J4D1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_comxhdk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sdw6P4aM_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_2MpiT648, VOf(Bf0));
    __hv_line_f(&sLine_ihxa2Dt4, VOf(Bf1));
    __hv_line_f(&sLine_TUotKkqF, VOf(Bf2));
    __hv_line_f(&sLine_Sjv4u47u, VOf(Bf3));
    __hv_line_f(&sLine_MvM3pL8B, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_mWNxxp4i, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_Y9rh05Qt, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_et17LT5F, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_VA5rFCuh, VOf(Bf1));
    __hv_line_f(&sLine_duLQELrS, VOf(Bf0));
    __hv_line_f(&sLine_oGOZKPio, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_NdjjWDLn, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_Nk6SXYYA, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_Mk7UQMb3, VOf(Bf5));
    __hv_line_f(&sLine_vd3GWE4x, VOf(Bf1));
    __hv_line_f(&sLine_MML8y9Wb, VOf(Bf2));
    __hv_line_f(&sLine_4ap6Fpn7, VOf(Bf4));
    __hv_line_f(&sLine_w1AuIthx, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_2SerxhIZ, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_CwgoX2NB, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_dmZzR6wY, VOf(Bf6));
    __hv_line_f(&sLine_r9XBIiK9, VOf(Bf2));
    __hv_line_f(&sLine_NQ1qTYDh, VOf(Bf1));
    __hv_line_f(&sLine_2WifDiJS, VOf(Bf5));
    __hv_line_f(&sLine_14KH4T7T, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_I744rcZQ, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_VCrWoiaz, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_qJkLsPcl, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_3DKRGW5S, VOf(Bf2));
    __hv_line_f(&sLine_PIUYuG98, VOf(Bf6));
    __hv_line_f(&sLine_rwdCeEGJ, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_21TTu73Y, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_0uyzyeYp, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_ETdqyVsQ, VOf(Bf8));
    __hv_line_f(&sLine_Ndo9TACG, VOf(Bf2));
    __hv_line_f(&sLine_kgF66fMt, VOf(Bf1));
    __hv_line_f(&sLine_1VGE0G6h, VOf(Bf7));
    __hv_line_f(&sLine_IYYCDG1p, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_UuvmkjtP, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Xllp4blt, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_L9wy0SbF, VOf(Bf9));
    __hv_tabread_f(&sTabread_BHAehiYw, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_2z4p89yi, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_Rtwni67f, VOf(Bf9));
    __hv_tabread_f(&sTabread_9DhyWZe9, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_f0gejDFD, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_ITpFJ3o4, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_X2bjEglF, VOf(Bf3));
    __hv_rpole_f(&sRPole_t8Y2SeGk, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_1nlOCVEf, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_rCnszJKm, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_oKwGIwwi, VIf(Bf3));
    __hv_varread_f(&sVarf_DgPQ5MeU, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_ovMCqtx2, VOf(Bf5));
    __hv_rpole_f(&sRPole_P0Z1Lc1N, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_Omp0QztU, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_XsVel6Nf, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_PgfyetM3, VIf(Bf5));
    __hv_varread_f(&sVarf_FPRlUv2i, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_O7OuF9HX, VOf(Bf1));
    __hv_varread_f(&sVarf_9fqlzBXs, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_TnYRHVyD, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_VnNIqspL, VOf(Bf1));
    __hv_varread_f(&sVarf_aHX52VRt, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_ivNGQ2hZ, VOf(Bf1));
    __hv_rpole_f(&sRPole_5A4MzZJO, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_idzMh9sT, VIf(Bf8), &sEnv_idzMh9sT_sendMessage);
    __hv_varread_f(&sVarf_F6CXE34I, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_lVKQm5N2, VOf(Bf1));
    __hv_rpole_f(&sRPole_GmZ5XVHZ, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_ITpFJ3o4, VIf(Bf1));
    __hv_line_f(&sLine_X7pWH3wy, VOf(Bf1));
    __hv_line_f(&sLine_cCE8JiVQ, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_P1jV1PEO, VOf(Bf1));
    __hv_varread_f(&sVarf_ljY3vBxr, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_S78jRPEJ, VOf(Bf1));
    __hv_rpole_f(&sRPole_n2e1TkD0, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_0hJNJ1CW, VIf(Bf8), &sEnv_0hJNJ1CW_sendMessage);
    __hv_varread_f(&sVarf_O8jWdoHs, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_GznuRjsj, VOf(Bf1));
    __hv_rpole_f(&sRPole_2rsRoSpd, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_DgPQ5MeU, VIf(Bf1));
    __hv_varwrite_f(&sVarf_q8edYgq2, VIf(Bf2));
    __hv_varread_f(&sVarf_0M1XbEz4, VOf(Bf2));
    __hv_varread_f(&sVarf_l7DfYC8q, VOf(Bf1));
    __hv_line_f(&sLine_PsuWTzC8, VOf(Bf8));
    __hv_tabread_f(&sTabread_QRXUWCl6, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_Eyq1UhVs, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_I2xYjQg7, VOf(Bf8));
    __hv_tabread_f(&sTabread_k5q0SgAa, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_WYEUeB51, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_LKAr5mxL, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_7qJ6v8qg, VOf(Bf2));
    __hv_rpole_f(&sRPole_Zq6s2x3M, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_6NhlGK18, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_RQJt7UMI, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_nIXEbvKF, VIf(Bf2));
    __hv_varread_f(&sVarf_LPuyhBSB, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_CBRXELsm, VOf(Bf1));
    __hv_rpole_f(&sRPole_cHe8faaM, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_H1qDEEXH, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_fp26OIgO, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_qzfDxLi3, VIf(Bf1));
    __hv_varread_f(&sVarf_epnkhGKF, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_zpFu6NEx, VOf(Bf3));
    __hv_varread_f(&sVarf_BrG2ex7S, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_lMl5VLzP, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_w0TFJN1c, VOf(Bf3));
    __hv_varread_f(&sVarf_DuQKnmd4, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_BYZb8kxx, VOf(Bf3));
    __hv_rpole_f(&sRPole_Doq60Cmm, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_476lIAOO, VIf(Bf9), &sEnv_476lIAOO_sendMessage);
    __hv_varread_f(&sVarf_Qai4odmV, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_yUji54x6, VOf(Bf3));
    __hv_rpole_f(&sRPole_XhFa8jyn, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_LKAr5mxL, VIf(Bf3));
    __hv_line_f(&sLine_4BeIaWg0, VOf(Bf3));
    __hv_line_f(&sLine_eOLu3U6x, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_4ZoQ17C6, VOf(Bf3));
    __hv_varread_f(&sVarf_6wev00gr, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_mFCSHpVE, VOf(Bf3));
    __hv_rpole_f(&sRPole_MGHLuNKT, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_uqw5blMT, VIf(Bf9), &sEnv_uqw5blMT_sendMessage);
    __hv_varread_f(&sVarf_hVrWLdi8, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_s5yqKLSQ, VOf(Bf3));
    __hv_rpole_f(&sRPole_fsZFOZH5, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_LPuyhBSB, VIf(Bf3));
    __hv_varwrite_f(&sVarf_eJX0Fbmm, VIf(Bf5));
    __hv_varread_f(&sVarf_YE4rYNXA, VOf(Bf5));
    __hv_varread_f(&sVarf_D4pnsN6b, VOf(Bf3));
    __hv_line_f(&sLine_kuQyRfmZ, VOf(Bf9));
    __hv_tabread_f(&sTabread_pnTWeUHV, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_4rIt9OwS, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_VXQ6647x, VOf(Bf9));
    __hv_tabread_f(&sTabread_VnMc8tu7, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_FuVhpRJE, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_qqABW3JY, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_b1SAE6bB, VOf(Bf5));
    __hv_rpole_f(&sRPole_djQDRWja, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_8puePUoS, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_7WDvGsGh, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_iePjZD9p, VIf(Bf5));
    __hv_varread_f(&sVarf_JCKneiLy, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_4Cnf9xuR, VOf(Bf3));
    __hv_rpole_f(&sRPole_jW6Sz8mx, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_VbWiSegL, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_Tt0X1jcd, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_Rw9AfzaL, VIf(Bf3));
    __hv_varread_f(&sVarf_a4BL4mle, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_NYYMYq9u, VOf(Bf2));
    __hv_varread_f(&sVarf_lXaurTNU, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_svDIXkYh, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_rKapemfn, VOf(Bf2));
    __hv_varread_f(&sVarf_BTwM9L8s, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Qy0xkJaV, VOf(Bf2));
    __hv_rpole_f(&sRPole_B82F7sS9, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_YxIu2KqR, VIf(Bf8), &sEnv_YxIu2KqR_sendMessage);
    __hv_varread_f(&sVarf_BEerFRF6, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_Qnu5SmC1, VOf(Bf2));
    __hv_rpole_f(&sRPole_NixnSUfZ, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_qqABW3JY, VIf(Bf2));
    __hv_line_f(&sLine_EblTejTF, VOf(Bf2));
    __hv_line_f(&sLine_tZlMqJEQ, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_M9VCZmam, VOf(Bf2));
    __hv_varread_f(&sVarf_8u9MtGVl, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_K6VZeEC9, VOf(Bf2));
    __hv_rpole_f(&sRPole_P42YgaSM, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_roJWg0Yp, VIf(Bf8), &sEnv_roJWg0Yp_sendMessage);
    __hv_varread_f(&sVarf_K9IfT6kN, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_cTQ5yx7M, VOf(Bf2));
    __hv_rpole_f(&sRPole_1qbEudMI, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_JCKneiLy, VIf(Bf2));
    __hv_varwrite_f(&sVarf_LKyF6c6Y, VIf(Bf1));
    __hv_varwrite_f(&sVarf_WSA0EmMH, VIf(Bf10));
    __hv_varwrite_f(&sVarf_kEcDlgMg, VIf(Bf11));
    __hv_varwrite_f(&sVarf_ikCcnThL, VIf(Bf12));
    __hv_varwrite_f(&sVarf_0M1XbEz4, VIf(Bf0));
    __hv_varwrite_f(&sVarf_l7DfYC8q, VIf(Bf6));
    __hv_varwrite_f(&sVarf_YE4rYNXA, VIf(Bf4));
    __hv_varwrite_f(&sVarf_D4pnsN6b, VIf(Bf7));
    __hv_varread_f(&sVarf_WSA0EmMH, VOf(Bf7));
    __hv_varread_f(&sVarf_kEcDlgMg, VOf(Bf4));
    __hv_varread_f(&sVarf_ikCcnThL, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_q8edYgq2, VOf(Bf6));
    __hv_varread_f(&sVarf_eJX0Fbmm, VOf(Bf7));
    __hv_varread_f(&sVarf_LKyF6c6Y, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
